@@ -287,7 +287,7 @@ void fors_bias(cpl_frameset *frames, const cpl_parameterlist *parameters)
     /* Save product */
     fors_dfs_save_image_err(frames, master_bias, MASTER_BIAS,
                         qc, NULL, parameters, fors_bias_name, 
-                        cpl_frameset_get_position(bias_frames, 0));
+                        cpl_frameset_get_position(bias_frames, 0), NULL);
     assure( !cpl_error_get_code(), return, "Saving %s failed",
             MASTER_BIAS);
     
