@@ -23,6 +23,7 @@
 
 #include "cpl_image.h"
 #include "cpl_mask.h"
+#include "fors_image.h"
 
 
 cpl_image * fors_bpm_create_combined_bpm
@@ -34,4 +35,8 @@ cpl_image * fors_bpm_create_combined_bpm
 (cpl_mask * non_linear_flat_mask,
  cpl_mask * saturated_flat_mask);
 
+void fors_bpm_image_list_make_explicit(fors_image_list * ima_list);
+
+void fors_bpm_image_make_explicit(const fors_image * ima);
+
 #endif /* FORS_BPM_H_ */
