@@ -82,7 +82,7 @@ fiera_config::~fiera_config()
 {
 }
 
-std::auto_ptr<fors::fiera_config>  ccd_config_read
+std::unique_ptr<fors::fiera_config>  ccd_config_read
 (const cpl_frame * source, const cpl_frame * bias_frame)
 {
     cpl_errorstate   error_prevstate = cpl_errorstate_get();
@@ -90,13 +90,13 @@ std::auto_ptr<fors::fiera_config>  ccd_config_read
     cpl_propertylist *header      = NULL;
     header = cpl_propertylist_load(cpl_frame_get_filename(source), 0);
     if (header == NULL) 
-        return std::auto_ptr<fors::fiera_config>(0);
+        return std::auto_ptr<fors::fiera_config>(nullptr);
 
-    std::auto_ptr<fors::fiera_config> 
+    std::unique_ptr<fors::fiera_config>
         ccd_config(new fors::fiera_config(header));
     cpl_propertylist_delete(header);
     if(!cpl_errorstate_is_equal(error_prevstate))
-        return std::auto_ptr<fors::fiera_config>(0);
+        return std::unique_ptr<fors::fiera_config>(nullptr);
     
     /* Update RON estimation from bias */
     cpl_propertylist * master_bias_header =
@@ -104,7 +104,7 @@ std::auto_ptr<fors::fiera_config>  ccd_config_read
     fors::update_ccd_ron(*ccd_config, master_bias_header);
     cpl_propertylist_delete(master_bias_header);
     if(!cpl_errorstate_is_equal(error_prevstate))
-        return std::auto_ptr<fors::fiera_config>(0);
+        return std::unique_ptr<fors::fiera_config>(nullptr);
     
     return ccd_config;
 }
