@@ -25,7 +25,8 @@
 
 void fors_image_variance_from_detmodel(fors_image * image,
                                        const mosca::ccd_config& ccd_config,
-                                       std::vector<double>& overscan_level);
+                                       std::vector<double>& overscan_level,
+									   double * average_overscan_level = NULL);
 
 void fors_image_variance_from_detmodel(fors_image_list * ima_list,
                                        const mosca::ccd_config& ccd_config,
