@@ -82,12 +82,12 @@ static char *strlower(char *s)
 
 static const cpl_frame* get_next_const_and_advance(cpl_frameset_iterator* it)
 {
-	const cpl_frame* to_ret = cpl_frameset_iterator_get_const(it);
+    const cpl_frame* to_ret = cpl_frameset_iterator_get_const(it);
 
-	if(to_ret)
-		cpl_frameset_iterator_advance(it, 1);
+    if(to_ret)
+        cpl_frameset_iterator_advance(it, 1);
 
-	return to_ret;
+    return to_ret;
 }
 
 /*----------------------------------------------------------------------------*/
@@ -199,7 +199,7 @@ errorstate_dump_one(unsigned self, unsigned first, unsigned last)
  */
 /*----------------------------------------------------------------------------*/
 void fors_begin(cpl_frameset *frames,
-		const char *description_short)
+        const char *description_short)
 {
     cpl_msg_info(cpl_func, "%s", PACKAGE_STRING);   
     cpl_msg_info(cpl_func, "%s", description_short);
@@ -341,6 +341,7 @@ fors_dfs_set_groups(cpl_frameset * set)
                      strcmp(tag, "TELLURIC_CONTAMINATION"       ) == 0 ||
                      strcmp(tag, "STD_FLUX_TABLE"               ) == 0 ||
                      strcmp(tag, "SPECPHOT_TABLE"               ) == 0 ||
+                     strcmp(tag, "MASTER_SPECPHOT_TABLE"        ) == 0 ||
                      strcmp(tag, PHOT_TABLE                     ) == 0 ||
                      strcmp(tag, PHOT_COEFF_TABLE               ) == 0 ||
                      strcmp(tag, EXTINCTION_PER_NIGHT           ) == 0 ||
@@ -1001,7 +1002,8 @@ dfs_save(cpl_frameset *frameset, const void *object, fors_type type,
          cpl_propertylist *extra_header,
          const cpl_parameterlist *parlist, const char *recipename,
          const cpl_frame *inherit_frame,
-		 const fors_dfs_idp_converter * converter)
+         const fors_dfs_idp_converter * converter,
+         const char *rm_regex)
 {
     char             *filename;
     cpl_frame        *frame;
@@ -1093,31 +1095,40 @@ dfs_save(cpl_frameset *frameset, const void *object, fors_type type,
     cpl_free((void *)version);
 
     if(converter){
-    	cpl_propertylist * idp_plist =
-    			fors_dfs_idp_converter_generate_idp_propertylist(converter, plist);
+        cpl_propertylist * idp_plist =
+                fors_dfs_idp_converter_generate_idp_propertylist(converter, plist);
 
-    	for(cpl_size i = 0; i < cpl_propertylist_get_size(idp_plist); ++i){
-    		const char * name = cpl_property_get_name(cpl_propertylist_get_const(idp_plist, i));
-    		cpl_propertylist_erase(plist, name);
-    	}
+        for(cpl_size i = 0; i < cpl_propertylist_get_size(idp_plist); ++i){
+            const char * name = cpl_property_get_name(cpl_propertylist_get_const(idp_plist, i));
+            cpl_propertylist_erase(plist, name);
+        }
 
-    	cpl_propertylist_append(plist, idp_plist);
-    	cpl_propertylist_delete(idp_plist);
+        cpl_propertylist_append(plist, idp_plist);
+        cpl_propertylist_delete(idp_plist);
     }
+
+    
+    /*
+     * Strip out unwanted keywords
+     */
+
+    if(rm_regex)
+        cpl_propertylist_erase_regexp(plist, rm_regex, 0);
+    
+
     /*
      * Write to disk
      */
-    
+
     if (type == FORS_TYPE_IMAGE_ERR) {
-        fors_image_save((fors_image *)object, plist, extra_header, filename);
+        fors_image_save(object, plist, extra_header, filename);
     }
     else if (type == FORS_TYPE_IMAGE) {
-        cpl_image_save((cpl_image *)object, filename, CPL_BPP_IEEE_FLOAT, plist,
+        cpl_image_save(object, filename, CPL_BPP_IEEE_FLOAT, plist,
                        CPL_IO_DEFAULT);
     }
     else {
-            cpl_table_save((cpl_table *)object, 
-                           plist, NULL, filename, CPL_IO_DEFAULT);
+        cpl_table_save(object, plist, NULL, filename, CPL_IO_DEFAULT);
     }
     
     if (cpl_error_get_code() != CPL_ERROR_NONE) {
@@ -1170,7 +1181,7 @@ fors_dfs_save_image(cpl_frameset *frameset, const cpl_image *image,
     dfs_save(frameset, image, FORS_TYPE_IMAGE, 
              category, header, NULL, 
              parlist, recipename, 
-             inherit_frame, NULL);
+             inherit_frame, NULL, NULL);
 }
 
 /*----------------------------------------------------------------------------*/
@@ -1209,7 +1220,7 @@ fors_dfs_save_image_mask(cpl_frameset *frameset, const cpl_image *image,
     dfs_save(frameset, image, FORS_TYPE_IMAGE, 
              category, header, NULL, 
              parlist, recipename, 
-             inherit_frame, NULL);
+             inherit_frame, NULL, NULL);
     
     extension_header = cpl_propertylist_new();
     cpl_propertylist_append_string(extension_header, 
@@ -1256,12 +1267,12 @@ fors_dfs_save_image_idp(cpl_frameset *frameset, const cpl_image *image,
                     cpl_propertylist *err_header,
                     const cpl_parameterlist *parlist, const char *recipename,
                     const cpl_frame *inherit_frame,
-					const fors_dfs_idp_converter * converter){
+                    const fors_dfs_idp_converter * converter){
 
     dfs_save(frameset, image, FORS_TYPE_IMAGE,
              category, header, err_header,
              parlist, recipename,
-             inherit_frame, converter);
+             inherit_frame, converter, NULL);
 }
 
 
@@ -1292,12 +1303,12 @@ fors_dfs_save_image_err(cpl_frameset *frameset, const fors_image *image,
                     const char *category, cpl_propertylist *header,
                     cpl_propertylist *err_header,
                     const cpl_parameterlist *parlist, const char *recipename,
-                    const cpl_frame *inherit_frame)
+                    const cpl_frame *inherit_frame, const char *rm_regex)
 {
     dfs_save(frameset, image, FORS_TYPE_IMAGE_ERR, 
              category, header, err_header, 
              parlist, recipename, 
-             inherit_frame, NULL);
+             inherit_frame, NULL, rm_regex);
 }
 
 /*----------------------------------------------------------------------------*/
@@ -1337,7 +1348,7 @@ fors_dfs_save_image_err_mask(cpl_frameset *frameset, const fors_image *image,
     dfs_save(frameset, image, FORS_TYPE_IMAGE_ERR, 
              category, header, NULL, 
              parlist, recipename, 
-             inherit_frame, NULL);
+             inherit_frame, NULL, NULL);
     
     extension_header = cpl_propertylist_new();
     cpl_propertylist_append_string(extension_header, 
@@ -1446,7 +1457,7 @@ fors_dfs_save_table(cpl_frameset *frameset, const cpl_table *table,
     dfs_save(frameset, table, FORS_TYPE_TABLE, 
              category, header, NULL, 
              parlist, recipename, 
-             inherit_frame, NULL);
+             inherit_frame, NULL, NULL);
 }
 
 void
@@ -1458,7 +1469,7 @@ fors_dfs_save_table_idp(cpl_frameset *frameset, const cpl_table *table,
     dfs_save(frameset, table, FORS_TYPE_TABLE,
              category, header, NULL,
              parlist, recipename,
-             inherit_frame, conv);
+             inherit_frame, conv, NULL);
 }
 
 /*----------------------------------------------------------------------------*/
@@ -1757,7 +1768,7 @@ int dfs_equal_keyword(cpl_frameset *frameset, const char *keyword)
 
     while ((frame = get_next_const_and_advance(it)) != NULL){
 
-    	reference = cpl_propertylist_load(cpl_frame_get_filename(frame), 0);
+        reference = cpl_propertylist_load(cpl_frame_get_filename(frame), 0);
         if (cpl_error_get_code() == CPL_ERROR_BAD_FILE_FORMAT) {
             cpl_error_reset();
             continue;
@@ -1783,7 +1794,7 @@ int dfs_equal_keyword(cpl_frameset *frameset, const char *keyword)
 
             cpl_propertylist_delete(reference);
             cpl_frameset_iterator_delete(it);
-			cpl_free(rstring);
+            cpl_free(rstring);
             return 0;
         }
 
@@ -1794,8 +1805,8 @@ int dfs_equal_keyword(cpl_frameset *frameset, const char *keyword)
 
     if (!found)
     {
-    	cpl_free(rstring);
-    	return 1;
+        cpl_free(rstring);
+        return 1;
     }
     it =  cpl_frameset_iterator_new(frameset);
 
@@ -1844,7 +1855,7 @@ int dfs_equal_keyword(cpl_frameset *frameset, const char *keyword)
     }
 
     cpl_frameset_iterator_delete(it);
-	cpl_free(rstring);
+    cpl_free(rstring);
 
     return 1;
 
@@ -1860,27 +1871,26 @@ int dfs_equal_keyword(cpl_frameset *frameset, const char *keyword)
  * @return CPL_ERROR_NONE of corresponding cpl_error_code on error.
  */
 cpl_error_code dfs_save_table_ext(cpl_table        * table,
-				  const char             * tag,
-				  cpl_propertylist * extheader)
+                  const char             * tag,
+                  cpl_propertylist * extheader)
 {
     char * filename = (char*)cpl_calloc(strlen(tag) + 6, sizeof(char));
     cpl_propertylist * header;
 
     if (extheader) { 
-	header = cpl_propertylist_duplicate(extheader);
-
-	cpl_propertylist_erase_regexp(header, 
+        header = cpl_propertylist_duplicate(extheader);
+        cpl_propertylist_erase_regexp(header, 
                                       "^ESO DPR |^ARCFILE$|^ORIGFILE$", 0);
     } else {
-	header = NULL;
+        header = NULL;
     }
 
     strlower(strcpy(filename, tag));
     strcat(filename, ".fits");
     
     if (cpl_table_save(table, NULL, header, filename, CPL_IO_EXTEND)) {
-	cpl_free(filename);
-	cpl_ensure_code(0, CPL_ERROR_FILE_IO);
+        cpl_free(filename);
+        cpl_ensure_code(0, CPL_ERROR_FILE_IO);
     }
     
     cpl_propertylist_delete(header);
@@ -1899,29 +1909,28 @@ cpl_error_code dfs_save_table_ext(cpl_table        * table,
  * @return CPL_ERROR_NONE of corresponding cpl_error_code on error.
  */
 cpl_error_code dfs_save_image_ext(cpl_image        * image,
-				  const char             * tag,
-				  cpl_propertylist * extheader)
+                  const char             * tag,
+                  cpl_propertylist * extheader)
 {
     char * filename = (char*)cpl_calloc(strlen(tag) + 6, sizeof(char));
     
     cpl_propertylist * header;
 
     if (extheader) {
-	header = cpl_propertylist_duplicate(extheader);
-
-	cpl_propertylist_erase_regexp(header, 
+        header = cpl_propertylist_duplicate(extheader);
+        cpl_propertylist_erase_regexp(header, 
                                       "^ESO DPR |^ARCFILE$|^ORIGFILE$", 0);
     } else {
-	header = NULL;
+        header = NULL;
     }
 
     strlower(strcpy(filename, tag));
     strcat(filename, ".fits");
     
-    if (cpl_image_save(image, filename, CPL_BPP_IEEE_FLOAT,
-		       header, CPL_IO_EXTEND)) {
-	cpl_free(filename);
-	cpl_ensure_code(0, CPL_ERROR_FILE_IO);
+    if (cpl_image_save(image, filename, CPL_BPP_IEEE_FLOAT, header,
+                       CPL_IO_EXTEND)) {
+        cpl_free(filename);
+        cpl_ensure_code(0, CPL_ERROR_FILE_IO);
     }
     
     cpl_propertylist_delete(header);
@@ -1942,10 +1951,10 @@ cpl_error_code dfs_save_image_ext(cpl_image        * image,
  * @return CPL_ERROR_NONE of corresponding cpl_error_code on error.
  */
 cpl_error_code dfs_save_image_null(cpl_frameset * frameset,
-				   cpl_parameterlist * parlist,
-				   const char * tag,
-				   const char * recipename,
-				   const char * version)
+                   cpl_parameterlist * parlist,
+                   const char * tag,
+                   const char * recipename,
+                   const char * version)
 {
 
     char * filename = (char*)cpl_calloc(strlen(tag) + 6, sizeof(char));
@@ -1953,15 +1962,15 @@ cpl_error_code dfs_save_image_null(cpl_frameset * frameset,
     cpl_error_code error;
 
     cpl_propertylist * pro = cpl_propertylist_new();
-		
+
     cpl_propertylist_append_string(pro, "ESO PRO CATG", tag);
 
     strlower(strcpy(filename, tag));
     strcat(filename, ".fits");
 
     error = cpl_dfs_save_image(frameset, NULL, parlist, frameset, NULL, NULL,
-			       CPL_BPP_IEEE_FLOAT, recipename, pro,
-			       NULL, version, filename);
+                               CPL_BPP_IEEE_FLOAT, recipename, pro,
+                               NULL, version, filename);
     
     cpl_free(filename);
     cpl_propertylist_delete(pro);
