@@ -82,6 +82,7 @@ cpl_error_code fors_dfs_idp_property_converter_convert(const fors_dfs_idp_proper
 
 	cpl_property_set_name(p, self->dest_key);
 	cpl_property_set_comment(p, self->dest_comment);
+	cpl_propertylist_erase(append_to_list, self->dest_key);
 	cpl_propertylist_append_property(append_to_list, p);
 	cpl_property_delete(p);
 	return CPL_ERROR_NONE;
@@ -183,11 +184,12 @@ fors_dfs_idp_property_converter_list_get_const(const fors_dfs_idp_property_conve
  * @brief    Constructor for fors_dfs_idp_converter
  * @return   a newly allocated fors_dfs_idp_converter
  */
-fors_dfs_idp_converter * fors_dfs_idp_converter_new(void){
+fors_dfs_idp_converter * fors_dfs_idp_converter_new(const cpl_boolean append_mjd_end){
 	fors_dfs_idp_converter * to_ret = cpl_calloc(1, sizeof(*to_ret));
 
 	to_ret->converters = fors_dfs_idp_property_converter_list_new();
 	to_ret->defaults_values = cpl_propertylist_new();
+	to_ret->append_mjd_end = append_mjd_end;
 	return to_ret;
 }
 
@@ -348,42 +350,50 @@ fors_dfs_idp_converter_generate_idp_propertylist(const fors_dfs_idp_converter *
 	if(self->defaults_values)
 		cpl_propertylist_append(new_list, self->defaults_values);
 
-	double mjd_end = 0;
-	cpl_error_code err = calculate_mjd_end(prod_plist, &mjd_end);
+	if(self->append_mjd_end){
+		double mjd_end = 0;
+		cpl_error_code err = calculate_mjd_end(prod_plist, &mjd_end);
 
-	if(!err){
-		cpl_propertylist_append_double(new_list, "MJD-END", mjd_end);
-		cpl_propertylist_set_comment(new_list, "MJD-END", "End of observations (days)");
+		if(!err){
+			cpl_propertylist_append_double(new_list, "MJD-END", mjd_end);
+			cpl_propertylist_set_comment(new_list, "MJD-END", "End of observations (days)");
+		}
+		else{
+			cpl_msg_warning(cpl_func, "Failure in calculating MJD-END");
+		}
 	}
-	else{
-		cpl_msg_warning(cpl_func, "Failure in calculating MJD-END");
-	}
-
 	return new_list;
 }
 
+
 /**
  * @brief    Generator of a new fors_dfs_idp_converter for imaging
  * @param    bias_plist     the master bias header (can NOT be null)
- * @param    phot_plist     the photometry plist (can be null)
+ * @param    phot_data      the zp data coming from photometry
  * @param    img     		the science image
  *
  * @return   fors_dfs_idp_converter for imaging
  */
 fors_dfs_idp_converter *
 fors_generate_imaging_idp_converter(const cpl_propertylist * bias_plist,
-		const cpl_propertylist * phot_plist,
-		const fors_image * img){
+		const fors_idp_zp_data * phot_data,
+		const fors_image * img,
+		const double crder, const double ra,
+		const double dec, const double skysqdeg,
+		const double psf_fwhm, const double elliptic,
+		const double ab_mag_lim, const double ab_mag_sat,
+                const double exptime){
 
 	const char * cunit_val = "deg";
 	const char * bunit_val = "adu";
 
-	fors_dfs_idp_converter * to_ret = fors_dfs_idp_converter_new();
+	fors_dfs_idp_converter * to_ret = fors_dfs_idp_converter_new(CPL_TRUE);
 
 	fors_dfs_idp_converter_add_conversion(to_ret, "ESO INS FILT1 NAME","FILTER","Filter name", NULL);
+	fors_dfs_idp_converter_add_conversion(to_ret, "ESO DET OUT1 CONAD","GAIN","Number of electrons per data unit", NULL);
 	fors_dfs_idp_converter_add_conversion(to_ret, "ESO DET WIN1 DIT1", "DIT", "Integration Time", NULL);
-	//fors_dfs_idp_converter_add_conversion(to_ret, "ESO DET WIN1 DIT1", "EXPTIME");
-	fors_dfs_idp_converter_add_conversion(to_ret, "ESO DET WIN1 DIT1", "TEXPTIME", "Total integration time of all exposures (s)", NULL);
+	fors_dfs_idp_converter_add_real_default(to_ret,"EXPTIME", "Total integration time", exptime);
+	fors_dfs_idp_converter_add_real_default(to_ret,"TEXPTIME", "Total integration time of all exposures (s)", exptime);
 	fors_dfs_idp_converter_add_conversion(to_ret, "ESO OBS PROG ID", "PROG_ID","ESO programme identification", NULL);
 	fors_dfs_idp_converter_add_conversion(to_ret, "ESO OBS ID", "OBID1","Observation block ID", NULL);
 
@@ -392,8 +402,6 @@ fors_generate_imaging_idp_converter(const cpl_propertylist * bias_plist,
 		fors_dfs_idp_converter_add_conversion(to_ret, "ESO QC RON", "EFFRON", "Median effective readout noise", bias_plist);
 	}
 
-	fors_dfs_idp_converter_add_conversion(to_ret, "RA", "FPRA", "Footprint (J2000.0)", NULL);
-	fors_dfs_idp_converter_add_conversion(to_ret, "DEC", "FPDE" ,"Footprint (J2000.0)", NULL);
 	fors_dfs_idp_converter_add_conversion(to_ret, "ESO PRO TECH", "OBSTECH", "Data product category", NULL);
 	fors_dfs_idp_converter_add_conversion(to_ret, "ESO PRO REC1 RAW1 NAME", "PROV1", "Originating science file", NULL);
 	fors_dfs_idp_converter_add_conversion(to_ret, "ESO PRO REC1 PIPE ID", "PROCSOFT", "Data reduction software/system with version no.", NULL);
@@ -410,6 +418,7 @@ fors_generate_imaging_idp_converter(const cpl_propertylist * bias_plist,
 	fors_dfs_idp_converter_add_string_default(to_ret,"CUNIT1","Unit of coordinate transformation", cunit_val);
 	fors_dfs_idp_converter_add_string_default(to_ret,"CUNIT2","Unit of coordinate transformation", cunit_val);
 	fors_dfs_idp_converter_add_real_default(to_ret,"CSYER1", "Systematic error", 5.0);
+	fors_dfs_idp_converter_add_real_default(to_ret,"CRDER1", "Random error", crder);
 	fors_dfs_idp_converter_add_string_default(to_ret,"PHOTSYS", "Photometric system VEGA or AB", "VEGA");
 
 
@@ -418,13 +427,19 @@ fors_generate_imaging_idp_converter(const cpl_propertylist * bias_plist,
 	fors_dfs_idp_converter_add_boolean_default(to_ret, "APMATCHD", "TRUE if fluxes are aperture-matched", CPL_FALSE);
 	fors_dfs_idp_converter_add_boolean_default(to_ret, "ISAMP", "TRUE if image represents partially sampled sky", CPL_FALSE);
 
-	if(phot_plist){
-		fors_dfs_idp_converter_add_conversion(to_ret, "ESO QC INSTRUMENT ZEROPOINT", "PHOTZP",
-				"Photometric zeropoint MAG=-2.5*log(data)+PHOTZP",
-				phot_plist);
-		fors_dfs_idp_converter_add_conversion(to_ret, "ESO QC INSTRUMENT ZEROPOINT ERROR", "PHOTZPER",
-				"Uncertainty on PHOTZP", phot_plist);
-	}
+
+	fors_dfs_idp_converter_add_real_default(to_ret,"PHOTZP", "Photometric zeropoint MAG=-2.5*log(data)+PHOTZP", phot_data->zp);
+	fors_dfs_idp_converter_add_real_default(to_ret,"PHOTZPER", "Uncertainty on PHOTZP", phot_data->zp_e);
+
+	fors_dfs_idp_converter_add_real_default(to_ret,"RA", "Image centre (J2000.0)", ra);
+	fors_dfs_idp_converter_add_real_default(to_ret,"DEC", "Image centre (J2000.0)", dec);
+	fors_dfs_idp_converter_add_real_default(to_ret,"SKYSQDEG", "Sky coverage in units of square degrees", skysqdeg);
+
+	fors_dfs_idp_converter_add_real_default(to_ret,"PSF_FWHM", "Spatial resolution (arcsec)", psf_fwhm);
+	fors_dfs_idp_converter_add_real_default(to_ret,"ELLIPTIC", "Average ellipticity of point sources", elliptic);
+	fors_dfs_idp_converter_add_real_default(to_ret,"ABMAGLIM", "5-sigma limiting AB magnitude for point sources", ab_mag_lim);
+	fors_dfs_idp_converter_add_real_default(to_ret,"ABMAGSAT", "Saturation limit for point sources (AB mags)", ab_mag_sat);
+
 
 	return to_ret;
 }
