@@ -31,6 +31,7 @@
 
 #include <cmath>
 #include <functional>
+#include <sstream>
 #include <fors_flat_normalise.h>
 #include <moses.h>
 #include <image_smooth.h>
@@ -56,13 +57,15 @@ fors::flat_normaliser::~flat_normaliser()
  * @param flat        Image containing the original flat field spectra
  * @param wave_cal    The wavelength calibration
  * @param spatial     Spatial calibration image
+ * @param calib_slits Calibrated slits
  * @param slits       Table with slits positions
  * @param polytraces  Coefficients of spectral curvature polynomials
  * @param blue        Start lambda to process
  * @param red         End lambda to process
  * @param dispersion  Mean spectral dispersion
  * @param spa_smooth_radius   Number of pixels for smoothing kernel in spatial axis
- * @param disp_smooth_radius  Number of pixels for smoothing kernel in dispersion axis
+ * @param disp_smooth_radius  Number of pixels for smoothing kernel in dispersion axis (median)
+ * @param disp_smooth_radius_aver  Number of pixels for smoothing kernel in dispersion axis (average)
  * @param spa_fit_polyorder   Order for polynomial fit along spatial axis
  * @param disp_fit_knots      Number of knots in the spline fitting along dispersion axis
  * @param fit_threshold       values below this will be igonred in the fits 
@@ -85,12 +88,11 @@ fors::flat_normaliser::~flat_normaliser()
  */ 
 int fors::flat_normaliser::mos_normalise
 (mosca::image& flat, const mosca::wavelength_calibration& wave_cal,
- cpl_image *spatial, cpl_table *slits, cpl_table *polytraces, 
- double blue, double red, 
- double dispersion,
- int spa_smooth_radius, int disp_smooth_radius, 
- int spa_fit_polyorder, int disp_fit_nknots,
- double fit_threshold)
+ cpl_image *spatial, const std::vector<mosca::calibrated_slit>& calib_slits,
+ cpl_table *slits, cpl_table *polytraces, double blue, double red,
+ double dispersion, int spa_smooth_radius, int disp_smooth_radius,
+ int disp_smooth_radius_aver,
+ int spa_fit_polyorder, int disp_fit_nknots, double fit_threshold)
 {
     const char     *func = "mos_mosflat_normalise";
 
@@ -204,8 +206,22 @@ int fors::flat_normaliser::mos_normalise
 
         cpl_image * exslit_orig =
                 cpl_image_extract(rectified, xlow, ylow, xhig, yhig);
+
         mosca::image im_exslit_orig(exslit_orig, true);
         
+        std::vector<mosca::calibrated_slit>::const_iterator slit_it;
+        for(std::vector<mosca::calibrated_slit>::const_iterator it = calib_slits.begin();
+           it != calib_slits.end(); ++it)
+        {
+           if(it->slit_id() == slit_id[i])
+           {
+               slit_it = it;
+               break;
+           }
+        }
+
+
+
         int  final_spa_smooth_radius = spa_smooth_radius;
         if (im_exslit_orig.size_spatial() / 2 < spa_smooth_radius)
         {
@@ -215,15 +231,26 @@ int fors::flat_normaliser::mos_normalise
                             spa_smooth_radius, final_spa_smooth_radius);
         }
 
-        
+        mosca::image norm_weigths = get_normalization_weights_mos(*slit_it,
+                flat.dispersion_axis(), slits, polytraces, blue, red,
+                dispersion, reference, xlow, ylow, xhig, yhig);
+
         std::vector<float> slit_spa_norm_profile;
         std::vector<float> slit_disp_norm_profile;
-        mosca::image normslit = mosca::image_normalise<float>(im_exslit_orig, 
-                                      final_spa_smooth_radius, disp_smooth_radius,
-                                      spa_fit_polyorder, disp_fit_nknots, 
-                                      fit_threshold, slit_spa_norm_profile,
+
+        mosca::image normslit = mosca::image_normalise(im_exslit_orig,
+                                      norm_weigths, final_spa_smooth_radius,
+                                      disp_smooth_radius, disp_smooth_radius_aver,
+				      spa_fit_polyorder,
+                                      disp_fit_nknots, fit_threshold,
+                                      slit_spa_norm_profile,
                                       slit_disp_norm_profile);
 
+        if(cpl_error_get_code()){
+        	cpl_msg_error(cpl_func, "Unable to normalize slit %i", slit_it->slit_id());
+        	return cpl_error_get_code();
+        }
+
         //Normalisation factor used for flat profile
         double prof_val_waveref = -1;
         try
@@ -250,6 +277,8 @@ int fors::flat_normaliser::mos_normalise
         catch(std::runtime_error& ex) {
         	cpl_msg_warning(cpl_func, "%s", ex.what());
         }
+
+
         //get_middle_slit_valid_calib errors ignored
         for(size_t i_prof = 0; i_prof < slit_disp_norm_profile.size(); i_prof++)
             slit_disp_norm_profile[i_prof] /= prof_val_waveref;
@@ -409,7 +438,7 @@ int fors::flat_normaliser::mos_normalise
         cpl_polynomial_delete(polytop);
         cpl_polynomial_delete(polybot);
     }
-    
+
     //TODO: What happens with inter-slit flux conservation. In principle the overall level
     //difference across slits should be conserved.
 
@@ -420,7 +449,7 @@ int fors::flat_normaliser::mos_normalise
 
     m_normalisation_image = mosca::image(smo_flat, true);
     
-    return 0;
+    return cpl_error_get_code();
 }
     
 
@@ -429,11 +458,13 @@ int fors::flat_normaliser::mos_normalise
  * @brief 
  *   Normalise a long slit flat field exposure
  *  
- * @param flat        Image containing the original flat field spectra
+ * @param flat                  Image containing the original flat field spectra
+ * @param wave_cal              Wave calibration object
  * @param spa_smooth_radius     Radius of smoothing box along the spatial direction
- * @param disp_smooth_radius     Radius of smoothing box along the dispersion direction
- * @param spa_fit_polyorder   Order of fitting polynomial along the spatial direction
- * @param disp_fit_polyorder   Order of fitting polynomial along the dispersion direction
+ * @param disp_smooth_radius    Radius of smoothing box along the dispersion direction (median)
+ * @param disp_smooth_radius_aver Radius of smoothing box along the dispersion direction (average)
+ * @param spa_fit_polyorder     Order of fitting polynomial along the spatial direction
+ * @param disp_fit_polyorder    Order of fitting polynomial along the dispersion direction
  *  
  * @return The smoothed flat field exposure used for normalisation
  *
@@ -448,11 +479,10 @@ int fors::flat_normaliser::mos_normalise
  * independently for each column/row of the image.
  */
 int fors::flat_normaliser::lss_normalise
-(mosca::image& flat,
- const mosca::wavelength_calibration& wave_cal,
- int spa_smooth_radius, int disp_smooth_radius, 
- int spa_fit_polyorder, int disp_fit_nknots,
- double fit_threshold)
+(mosca::image& flat, const mosca::wavelength_calibration& wave_cal,
+ const std::vector<mosca::calibrated_slit>& calib_slits,
+ int spa_smooth_radius, int disp_smooth_radius, int disp_smooth_radius_aver,
+ int spa_fit_polyorder, int disp_fit_nknots, double fit_threshold)
 {
     const char     *func = "mos_normalise_longflat";
 
@@ -478,21 +508,26 @@ int fors::flat_normaliser::lss_normalise
                         spa_smooth_radius, final_spa_smooth_radius);
     }
 
+    mosca::image  weigth_flat = get_normalization_weights_lss(calib_slits[0],
+            flat.dispersion_axis());
+
     std::vector<float> slit_spa_norm_profile;
     std::vector<float> slit_disp_norm_profile;
-    mosca::image normslit = mosca::image_normalise<float>(smoothed_flat, 
+    mosca::image normslit = mosca::image_normalise(smoothed_flat, weigth_flat,
                                   final_spa_smooth_radius, disp_smooth_radius,
-                                  spa_fit_polyorder, disp_fit_nknots, 
-                                  fit_threshold, slit_spa_norm_profile,
-                                  slit_disp_norm_profile);
+				  disp_smooth_radius_aver,
+                                  spa_fit_polyorder, disp_fit_nknots, fit_threshold,
+                                  slit_spa_norm_profile, slit_disp_norm_profile);
+
     //Get the pixel of the waveref at the middle of the slit
     double pix_waveref = wave_cal.get_pixel(flat.size_spatial() / 2.,
                                             wave_cal.get_refwave());
     int pix_waveref_left = std::floor(pix_waveref);
     int pix_waveref_rigth = std::ceil(pix_waveref);
+
     //Normalise by the value at waveref
     double prof_val_waveref = 1;
-    if(pix_waveref_left>=0 && pix_waveref_rigth < flat.size_dispersion())
+    if(pix_waveref_left >= 0 && pix_waveref_rigth < flat.size_dispersion())
         prof_val_waveref = (slit_disp_norm_profile[pix_waveref_left] +
                             slit_disp_norm_profile[pix_waveref_rigth]) / 2.;
     for(size_t i_prof = 0; i_prof < slit_disp_norm_profile.size(); i_prof++)
@@ -501,7 +536,6 @@ int fors::flat_normaliser::lss_normalise
     m_wave_profiles.push_back(slit_disp_norm_profile);
     m_wave_profiles_norm.push_back(prof_val_waveref);
 
-
     //Finally divide by the smoothed version of the flat.
     cpl_image_divide(flat_im, normslit.get_cpl_image());
     cpl_image_divide(flat_err, normslit.get_cpl_image());
@@ -551,6 +585,15 @@ const std::vector<std::vector<float> >& fors::flat_normaliser::get_wave_profiles
     return m_wave_profiles;
 }
 
+static
+void dump_vector(const std::vector<float>& v){
+    std::stringstream ss;
+    for(const auto& e : v){
+        ss<< e <<" ";
+    }
+    cpl_msg_info(cpl_func, "For FLAT SED normalization the following widths are used %s", ss.str().c_str());
+}
+
 std::vector<float> fors::flat_normaliser::get_wave_profiles_norm
 (double mflat_exptime,
  const std::vector<float>& slit_widths,
@@ -561,9 +604,11 @@ std::vector<float> fors::flat_normaliser::get_wave_profiles_norm
         throw std::invalid_argument("Vector sizes do not match");
     std::vector<float> wave_profiles_norm_scaled;
     
+    dump_vector(slit_widths);
+
     for(size_t i = 0; i < m_wave_profiles_norm.size(); ++i)
     {
-        float scale = mflat_exptime * slit_widths[i] * slit_lengths[i];
+        float scale = mflat_exptime * slit_widths[i];
         if(scale == 0 )
             scale = 1;  //In some cases the length has been detected as 0.
         wave_profiles_norm_scaled.push_back(m_wave_profiles_norm[i] / scale);
@@ -616,11 +661,10 @@ cpl_image * fors::flat_normaliser::get_wave_profiles_im_mapped
             catch(std::runtime_error& ex) {} 
             for(cpl_size i_wave = 0; i_wave < nl; ++i_wave)
             {
-                int null;
                 double wave = firstLambda + i_wave * dispersion;
                 double pixel = wave_cal.get_pixel(slit_pos_good_wavecal, wave);
                 int i_pix = std::ceil(pixel+0.5);
-                if(i_pix>= 0 && i_pix <m_wave_profiles.front().size())
+                if(i_pix >= 0 && i_pix < (int)m_wave_profiles.front().size())
                     cpl_image_set(mapped_flat_sed, i_wave+1, i_slit+1,
                                   m_wave_profiles[i_slit][i_pix]);
             }
@@ -630,3 +674,51 @@ cpl_image * fors::flat_normaliser::get_wave_profiles_im_mapped
     return mapped_flat_sed;
 }
 
+mosca::image fors::flat_normaliser::get_normalization_weights_mos(
+        const mosca::calibrated_slit& slit, const mosca::axis& flat_ax,
+        cpl_table *slits, cpl_table *polytraces,
+        const double blue, const double red, const double dispersion,
+        const double reference, const int xlow, const int ylow, const int xhig,
+        const int yhig) {
+
+    cpl_mask * slit_mask_whole =
+                   slit.get_mask_valid(flat_ax);
+    cpl_image * slit_mask_im = cpl_image_new_from_mask(slit_mask_whole);
+    cpl_image * slit_mask_im_d =  cpl_image_cast(slit_mask_im, CPL_TYPE_FLOAT);
+    cpl_image * slit_mask_rectified =
+           mos_spatial_calibration(slit_mask_im_d, slits, polytraces,
+                                   reference, blue, red, dispersion,
+                                   0, NULL);
+
+    //We don't consider fractional pixels yet
+    cpl_image_threshold(slit_mask_rectified, 0.99, 1.1, 0., 1.);
+
+    cpl_image * exslit_mask_rectified =
+           cpl_image_extract(slit_mask_rectified, xlow, ylow, xhig, yhig);
+    mosca::image slit_mask_im_mos(exslit_mask_rectified, true);
+    cpl_image_delete(slit_mask_rectified);
+    cpl_image_delete(slit_mask_im);
+    cpl_image_delete(slit_mask_im_d);
+    cpl_mask_delete(slit_mask_whole);
+
+    return slit_mask_im_mos;
+}
+
+mosca::image fors::flat_normaliser::get_normalization_weights_lss(
+        const mosca::calibrated_slit& slit, const mosca::axis& flat_ax) {
+
+    cpl_mask * slit_mask_whole =
+                   slit.get_mask_valid(flat_ax);
+    cpl_image * slit_mask_im = cpl_image_new_from_mask(slit_mask_whole);
+    cpl_image * slit_mask_im_d =  cpl_image_cast(slit_mask_im, CPL_TYPE_FLOAT);
+
+    //We don't consider fractional pixels yet
+    cpl_image_threshold(slit_mask_im_d, 0.99, 1.1, 0., 1.);
+
+    mosca::image slit_mask_im_lss(slit_mask_im_d, true);
+
+    cpl_image_delete(slit_mask_im);
+    cpl_mask_delete(slit_mask_whole);
+
+    return slit_mask_im_lss;
+}
