@@ -132,7 +132,7 @@ fors_image_new(cpl_image *data, cpl_image *variance)
             "You may contact usd-help@eso.org which can provide a workaround.",
             cpl_image_get_min(variance));
 
-    image = cpl_malloc(sizeof(*image));
+    image = (fors_image*)cpl_malloc(sizeof(*image));
 
     image->data = data;
     image->variance = variance;
@@ -1006,8 +1006,8 @@ fors_image_get_median(const fors_image *image, double *dmedian)
  * Coordinates are inclusive, counting from 1
  */
 void fors_image_crop(fors_image *image,
-		     int xlo, int ylo,
-		     int xhi, int yhi)
+                     int xlo, int ylo,
+                     int xhi, int yhi)
 {
     /* CPL is missing the function to locally extract an image,
        so this this inefficient CPL function */
@@ -1103,7 +1103,7 @@ fors_image_filter_median_create(const fors_image *image,
 
     const float *input_data  = cpl_image_get_data_float_const(input);
     float *smooth_data = cpl_image_get_data_float(smooth);
-    float *data = cpl_malloc((2*yradius + 1)*(2*xradius + 1)*sizeof(*data));
+    float *data = (float*)cpl_malloc((2*yradius + 1)*(2*xradius + 1)*sizeof(*data));
     
     int y;
     for (y = ystart; y < yend; y++) {
@@ -1774,7 +1774,7 @@ hdrl_imagelist * fors_image_list_to_hdrl(const fors_image_list * imalist)
 
         //Set the same mask for image and its associated error
         //This is required by hdrl_image.
-        cpl_mask * ima_mask = cpl_image_get_bpm_const(ima_data);
+        const cpl_mask * ima_mask = cpl_image_get_bpm_const(ima_data);
         cpl_mask * imaerr_mask = NULL;
         if(ima_mask != NULL)
             imaerr_mask = cpl_mask_duplicate(ima_mask);
