@@ -285,6 +285,9 @@ void fors_img_science(cpl_frameset *frames, const cpl_parameterlist *parameters)
         cleanup;
         return;
     }
+    assure( !generate_idp || cpl_frameset_get_size(illum_region_frames), return, 
+            "Input frames do not include " DETECTOR_ILLUMINATED_REGION". "
+            "IDP generation cannot be performed");
 
 
     /* Done finding frames */
@@ -384,28 +387,6 @@ void fors_img_science(cpl_frameset *frames, const cpl_parameterlist *parameters)
                          &sky_stats, &background, &sources);
     assure( !cpl_error_get_code(), return, "Could not extract objects");  
 
-    /* Trimm non-illuminated areas */
-    if(cpl_frameset_get_size(illum_region_frames) == 1)
-    {
-        cpl_frame * illum_region_frame = 
-            cpl_frameset_get_position(illum_region_frames, 0);
-        cpl_table * illum_region =
-            cpl_table_load(cpl_frame_get_filename(illum_region_frame), 1, 1);
-
-        /* Trimming science image. 
-         * Note that it also updates the header WCS in wcs_header */
-        bool match = fors_trimm_non_illum(sci, wcs_header, setting, illum_region);
-        /* Trimming flat field, needed to compute the weights for IDPs */
-        fors_trimm_non_illum(master_flat, NULL, setting, illum_region);
-        /* Trimming background */
-        fors_trimm_non_illum(&background, NULL, setting, illum_region);
-        if(!match)
-            cpl_msg_warning(cpl_func, "Table " DETECTOR_ILLUMINATED_REGION" does"
-                            " not contain matching detector and collimator. "
-                            "No trimming of non-illuminated regions applied");
-        cpl_table_delete(illum_region);
-    }
-
     /* QC */
     fors_qc_start_group(qc, fors_qc_dic_version, setting->instrument);
     
@@ -538,22 +519,57 @@ void fors_img_science(cpl_frameset *frames, const cpl_parameterlist *parameters)
 
     const cpl_frame * inherit_frame = cpl_frameset_get_position_const(sci_frame, 0);
 
-    if(generate_idp){
+    const char *del_kwords =
+            perform_preoverscan ? "^ESO DET OUT[0-9]+ (OV|PR)SC[XY]$" : NULL;
+    fors_dfs_save_image_err(frames, sci, SCIENCE_REDUCED_IMG, qc, NULL,
+                            parameters, fors_img_science_name, inherit_frame,
+                            del_kwords);
+    assure( !cpl_error_get_code(), return, "Saving %s failed",
+            SCIENCE_REDUCED_IMG);
 
+    dfs_save_image(frames, background, PHOT_BACKGROUND_SCI_IMG,
+                   product_header, parameters, fors_img_science_name, 
+                   setting->version);
+    assure( !cpl_error_get_code(), return, "Saving %s failed",
+            PHOT_BACKGROUND_SCI_IMG);
+
+    if (generate_idp) {
         double image_fwhm = 0; //in arcsec
         double image_fwhm_pix = 0; //in pixel
-        const bool fwhm_available = fors_img_idp_get_image_psf_fwhm(stars, setting,
-            sci_header, &image_fwhm, &image_fwhm_pix);
+        const bool fwhm_available = fors_img_idp_get_image_psf_fwhm(stars,
+            setting, sci_header, &image_fwhm, &image_fwhm_pix);
 
-        if(fwhm_available){
+        /* Trimm non-illuminated areas */
+        if (fwhm_available) {
+            cpl_frame * illum_region_frame = cpl_frameset_get_position(
+                illum_region_frames, 0);
+            const char * fname = cpl_frame_get_filename(illum_region_frame);
+            cpl_table * illum_region = cpl_table_load(fname, 1, 1);
 
-            fors_img_idp_quality qty(image_fwhm, image_fwhm_pix, ellipticity,
-                sky_stats.bkg_rms, sky_mag, average_overscan_level, sources);
+            /* Trimming science image. 
+             * Note that it also updates the header WCS in wcs_header */
+            bool match = fors_trimm_non_illum(sci, wcs_header, setting,
+                                              illum_region);
+            /* Trimming flat field, needed to compute the weights for IDPs */
+            fors_trimm_non_illum(master_flat, NULL, setting, illum_region);
 
-           fors_img_idp_save(frames, sci, qc, parameters,
-                inherit_frame, cpl_frameset_get_position(master_bias_frame, 0),
-                master_flat, idp_weights_threshold, IDP_Products_Filenames,
-                qty);
+            cpl_table_delete(illum_region);
+
+            if (match) {
+                cpl_propertylist_copy_property_regexp(qc, wcs_header, ".*", false);
+
+                fors_img_idp_quality qty(image_fwhm, image_fwhm_pix, ellipticity,
+                    sky_stats.bkg_rms, sky_mag, average_overscan_level, sources);
+
+                fors_img_idp_save(frames, sci, qc, parameters, inherit_frame,
+                    cpl_frameset_get_position(master_bias_frame, 0), master_flat,
+                    idp_weights_threshold, IDP_Products_Filenames, qty);
+            }
+            else {
+                cpl_msg_warning(cpl_func, "Detector & collimator not found in "
+                    DETECTOR_ILLUMINATED_REGION " table, aborting IDP generation");
+                cpl_error_reset();
+            }
         }
         else{
             cpl_msg_warning(cpl_func, "Unable to calculate PSF_FWHM, aborting IDP generation");
@@ -561,21 +577,7 @@ void fors_img_science(cpl_frameset *frames, const cpl_parameterlist *parameters)
         }
     }
 
-    fors_dfs_save_image_err(frames, sci, SCIENCE_REDUCED_IMG,
-                        qc, NULL, parameters, fors_img_science_name, 
-                        inherit_frame);
-
-    assure( !cpl_error_get_code(), return, "Saving %s failed",
-            SCIENCE_REDUCED_IMG);
-
     fors_image_delete(&sci);
-    
-    dfs_save_image(frames, background, PHOT_BACKGROUND_SCI_IMG,
-                   product_header, parameters, fors_img_science_name, 
-                   setting->version);
-    assure( !cpl_error_get_code(), return, "Saving %s failed",
-            PHOT_BACKGROUND_SCI_IMG);
-
     cpl_image_delete(background); background = NULL;
     
     /* Create, save FITS product */
@@ -604,7 +606,7 @@ void fors_img_science(cpl_frameset *frames, const cpl_parameterlist *parameters)
     cpl_table_erase_column(phot, "WEIGHT");
 
     fors_dfs_save_table(frames, sources, SOURCES_SCI,
-    		NULL, parameters, fors_img_science_name,
+                        NULL, parameters, fors_img_science_name,
                         cpl_frameset_get_position(sci_frame, 0));
 
     assure( !cpl_error_get_code(), return, "Saving %s failed",
