@@ -319,13 +319,13 @@ fors_img_screen_flat(cpl_frameset *frames, const cpl_parameterlist *parameters)
     /* Save products */
     fors_dfs_save_image_err(frames, master_screen_flat, MASTER_SCREEN_FLAT_IMG,
                         NULL, NULL, parameters, fors_img_screen_flat_name, 
-                        cpl_frameset_get_position(sflat_frames, 0));
+                        cpl_frameset_get_position(sflat_frames, 0), NULL);
     assure( !cpl_error_get_code(), return, "Saving %s failed",
             MASTER_SCREEN_FLAT_IMG);
     
     fors_dfs_save_image_err(frames, master_norm_flat, MASTER_NORM_FLAT_IMG,
                         qc, NULL, parameters, fors_img_screen_flat_name, 
-                        cpl_frameset_get_position(sflat_frames, 0));
+                        cpl_frameset_get_position(sflat_frames, 0), NULL);
     assure( !cpl_error_get_code(), return, "Saving %s failed",
             MASTER_NORM_FLAT_IMG);
     
