@@ -41,7 +41,7 @@ cpl_table * fors_compute_response
  double exptime, cpl_table *ext_table, double airmass, cpl_table *flux_table,
  const std::vector<double>& ignored_waves,
  const std::vector<std::pair<double, double> >& ignored_wave_ranges,
- int nknots, int degree, cpl_table *& response_interp,
+ int nknots, int degree, cpl_table *& response_obs_binning,
  double& flat_sed_norm_factor,
  const fors::detected_slits& det_slits)
 {
@@ -82,7 +82,6 @@ cpl_table * fors_compute_response
                                     "instrument response must be at least 1");
 
     int nx = cpl_image_get_size_x(spectra);
-    int ny = cpl_image_get_size_y(spectra);
 
     /*
      * Find brightest spectrum and duplicate it.
@@ -137,10 +136,12 @@ cpl_table * fors_compute_response
         for (int i_pix = 0; i_pix < nx; i_pix++)
         {
             int   null;
-            double profile_val  = cpl_image_get(mapped_flat_sed, i_pix+1, obj_slit+1, &null);
+            const double profile_val  = cpl_image_get(mapped_flat_sed, i_pix+1, obj_slit+1, &null);
+            const double val = cpl_image_get(spectrum_sedcorr, i_pix+1, 1, &null);
             if(profile_val != 0)
-                cpl_image_set(spectrum_sedcorr, i_pix+1, 1, 
-                        cpl_image_get(spectrum_sedcorr, i_pix+1, 1, &null) / profile_val);
+                cpl_image_set(spectrum_sedcorr, i_pix+1, 1, val / profile_val);
+            else
+            	cpl_image_set(spectrum_sedcorr, i_pix+1, 1, 0.0);
         }
         std::ostringstream norm_key;
         norm_key<< "ESO QC FLAT SED_"<<det_slits[obj_slit].slit_id()<<" NORM";
@@ -276,29 +277,15 @@ cpl_table * fors_compute_response
         cpl_table_copy_data_int(response_table, "USED_FIT", used_fit.data());
     }
 
-    /*Add IS_EXTRAPOLATED*/
-    {
-        cpl_table_new_column(response_table, "IS_EXTRAPOLATED", CPL_TYPE_INT);
-        std::vector<int> is_extrap(resp.wave_tab().size());
-        for(size_t i = 0; i < resp.wave_tab().size(); ++i)
-        {
-            const double wlen = resp.wave_tab()[i];
-            const bool is_ex = !(wlen >= resp.start_valid_wave_tab()
-                    && wlen <= resp.stop_valid_wave_tab());
-            is_extrap[i] = is_ex;
-        }
-        cpl_table_copy_data_int(response_table, "IS_EXTRAPOLATED", is_extrap.data());
-    }
-
     const bool inc_extrapolation = false;
-    response_interp = cpl_table_new(resp.wave_obs(inc_extrapolation).size());
-    cpl_table_new_column(response_interp, "WAVE", CPL_TYPE_DOUBLE);
-    cpl_table_set_column_unit(response_interp, "WAVE", "Angstrom");
-    cpl_table_copy_data_double(response_interp, "WAVE", &(resp.wave_obs(inc_extrapolation)[0]));
+    response_obs_binning = cpl_table_new(resp.wave_obs(inc_extrapolation).size());
+    cpl_table_new_column(response_obs_binning, "WAVE", CPL_TYPE_DOUBLE);
+    cpl_table_set_column_unit(response_obs_binning, "WAVE", "Angstrom");
+    cpl_table_copy_data_double(response_obs_binning, "WAVE", &(resp.wave_obs(inc_extrapolation)[0]));
 
-    cpl_table_new_column(response_interp, "EFFICIENCY", CPL_TYPE_DOUBLE);
-    cpl_table_set_column_unit(response_interp, "EFFICIENCY", "electron/photon");
-    cpl_table_copy_data_double(response_interp, "EFFICIENCY", &(resp.efficiency_fit_obs(inc_extrapolation)[0]));
+    cpl_table_new_column(response_obs_binning, "EFFICIENCY", CPL_TYPE_DOUBLE);
+    cpl_table_set_column_unit(response_obs_binning, "EFFICIENCY", "electron/photon");
+    cpl_table_copy_data_double(response_obs_binning, "EFFICIENCY", &(resp.efficiency_fit_obs(inc_extrapolation)[0]));
 
     if(mapped_flat_sed != NULL)
     {
@@ -316,10 +303,10 @@ cpl_table * fors_compute_response
                                   "RESPONSE_FFSED", "10^(-16) erg/(cm^2 electron)");
         cpl_table_copy_data_double(response_table, "RESPONSE_FFSED", &(resp_sedcorr.response_fit()[0]));
 
-        cpl_table_new_column(response_interp, "RESPONSE_FFSED", CPL_TYPE_DOUBLE);
-        cpl_table_set_column_unit(response_interp, 
+        cpl_table_new_column(response_obs_binning, "RESPONSE_FFSED", CPL_TYPE_DOUBLE);
+        cpl_table_set_column_unit(response_obs_binning, 
                                   "RESPONSE_FFSED", "10^(-16) erg/(cm^2 electron)");
-        cpl_table_copy_data_double(response_interp, "RESPONSE_FFSED", &(resp_sedcorr.response_fit_obs(inc_extrapolation)[0]));
+        cpl_table_copy_data_double(response_obs_binning, "RESPONSE_FFSED", &(resp_sedcorr.response_fit_obs(inc_extrapolation)[0]));
     }
     else
     {
@@ -328,10 +315,10 @@ cpl_table * fors_compute_response
                                   "RESPONSE", "10^(-16) erg/(cm^2 electron)");
         cpl_table_copy_data_double(response_table, "RESPONSE", &(resp.response_fit()[0]));
 
-        cpl_table_new_column(response_interp, "RESPONSE", CPL_TYPE_DOUBLE);
-        cpl_table_set_column_unit(response_interp, 
+        cpl_table_new_column(response_obs_binning, "RESPONSE", CPL_TYPE_DOUBLE);
+        cpl_table_set_column_unit(response_obs_binning, 
                                   "RESPONSE", "10^(-16) erg/(cm^2 electron)");
-        cpl_table_copy_data_double(response_interp, "RESPONSE", &(resp.response_fit_obs(inc_extrapolation)[0]));
+        cpl_table_copy_data_double(response_obs_binning, "RESPONSE", &(resp.response_fit_obs(inc_extrapolation)[0]));
     }
 
     return response_table;
@@ -349,7 +336,6 @@ void fors_science_correct_flat_sed
     cpl_size nslits = cpl_table_get_nrow(objects);
     int   maxobjects = 1;
     char  name[MAX_COLNAME];
-    int   null;
     snprintf(name, MAX_COLNAME, "object_%d", maxobjects);
     while (cpl_table_has_column(objects, name)) {
         maxobjects++;
