@@ -105,6 +105,7 @@ fors_setting_new_level(const cpl_frame *raw, cpl_msg_severity level)
     s->filter_name = NULL;
     s->read_clock = NULL;
     s->chip_id = NULL;
+    s->coll_name = NULL;
     s->instrument = NULL;
     s->version = NULL;
 
@@ -371,11 +372,31 @@ fors_setting_new_level(const cpl_frame *raw, cpl_msg_severity level)
             FORS_PFITS_CHIP_ID, filename);
 
     s->chip_id = cpl_strdup(s->chip_id);
-
+    //Trim trailing spaces
+    char * p;
+    while((p = strrchr(s->chip_id,' ')) != NULL && 
+	  s->chip_id+strlen(s->chip_id) == p+1)
+        *p = '\0';
 
     fors_msg(level, "Chip ID (%s) = %s", 
                  FORS_PFITS_CHIP_ID, s->chip_id);
 
+    s->coll_name = cpl_propertylist_get_string(header, FORS_PFITS_COLL_NAME);
+    if (CPL_ERROR_TYPE_MISMATCH == cpl_error_get_code()) {
+        cpl_msg_error(cpl_func, 
+                      "Keyword %s is not a string", 
+                      FORS_PFITS_COLL_NAME);
+    }
+    assure( !cpl_error_get_code(), return s, 
+            "Could not read %s from %s header", 
+            FORS_PFITS_COLL_NAME, filename);
+
+    s->coll_name = cpl_strdup(s->coll_name);
+
+
+    fors_msg(level, "Collimator name (%s) = %s", 
+                 FORS_PFITS_COLL_NAME, s->coll_name);
+
     cpl_msg_indent_less();
     
     cleanup;
@@ -463,6 +484,11 @@ fors_setting_verify(const fors_setting *ref_setting, const cpl_frame *frame,
                         input_setting->chip_id);
     }
 
+    if (strcmp(ref_setting->coll_name, input_setting->coll_name) != 0) {
+        cpl_msg_warning(cpl_func, "Incompatible collimator name: '%s'",
+                        input_setting->coll_name);
+    }
+
     if (strcmp(ref_setting->read_clock, input_setting->read_clock) != 0) {
         cpl_msg_warning(cpl_func, "Incompatible readout clock pattern: '%s'",
                         input_setting->read_clock);
@@ -501,6 +527,7 @@ void fors_setting_delete(fors_setting **s)
         if ((*s)->filter_name != NULL) cpl_free((void *)((*s)->filter_name));
         cpl_free((void *)((*s)->read_clock));
         cpl_free((void *)((*s)->chip_id));
+        cpl_free((void *)((*s)->coll_name));
         cpl_free((void *)((*s)->version));
         cpl_free((void *)((*s)->instrument));
         cpl_free(*s); *s = NULL;
