@@ -38,9 +38,10 @@ typedef struct
     const char * disp_coeff_tag;
     double spec_sye;
     double exptime;
+    const char * det_exp_num;
 }fors_spec_idp_save_info;
 
-void fors_spec_idp_save_idp_format(fors_spec_idp_save_info info, const cpl_image * calibrated,
+void fors_spec_idp_save_idp_format(fors_spec_idp_save_info& info, const cpl_image * calibrated,
     const cpl_image * calibrated_error, const cpl_image * bkg,
     const cpl_image * reduced, const cpl_image * reduced_err,
     const cpl_array * wlens, const cpl_table * obj_table);
