@@ -339,7 +339,7 @@ fors_star_brighter_than(const fors_star *s1,
                         const fors_star *s2,
                         void *data)
 {
-    data = data;
+    (void)data;
     return (s1->magnitude < s2->magnitude);
 }
 
@@ -374,7 +374,7 @@ double fors_star_distsq(const fors_star *s, const fors_star *t)
 double fors_star_extension(const fors_star *s, void *data)
 {
     assure( s != NULL, return -1, NULL );
-    data = data;
+    (void)data;
 
     /* return sqrt(s->semi_major * s->semi_minor); */
     return s->fwhm / TWOSQRT2LN2;
@@ -392,7 +392,7 @@ double fors_star_extension(const fors_star *s, void *data)
 double fors_star_fwhm(const fors_star *s, void *data)
 {
     assure( s != NULL, return -1, NULL );
-    data = data;
+    (void)data;
 
     return s->fwhm ;
 }
@@ -410,7 +410,7 @@ double fors_star_fwhm(const fors_star *s, void *data)
 double fors_star_stellarity(const fors_star *s, void *data)
 {
     assure( s != NULL, return -1, NULL );
-    data = data;
+    (void)data;
 
     return s->stellarity_index;
 }
@@ -428,7 +428,7 @@ double fors_star_stellarity(const fors_star *s, void *data)
 double fors_star_ellipticity(const fors_star *s, void *data)
 {
     assure( s != NULL, return -1, NULL );
-    data = data;
+    (void)data;
     
     if (s->semi_major <= 0) return 1;
     else return 1 - (s->semi_minor / s->semi_major);
@@ -494,7 +494,7 @@ fors_star_get_x(const fors_star *s, void *data)
 {
     assure( s != NULL, return -1, NULL );
 
-    data = data;
+    (void)data;
 
     return s->pixel->x;
 }
@@ -512,7 +512,7 @@ fors_star_get_y(const fors_star *s, void *data)
 {
     assure( s != NULL, return -1, NULL );
 
-    data = data;
+    (void)data;
 
     return s->pixel->y;
 }
@@ -531,7 +531,7 @@ fors_star_get_zeropoint(const fors_star *s, void *data)
 {
     assure( s     != NULL, return 0, NULL );
     assure( s->id != NULL, return 0, NULL );
-    data = data;
+    (void)data;
 
     return (s->id->magnitude - s->magnitude_corr);
 }
@@ -549,7 +549,7 @@ fors_star_get_zeropoint_err(const fors_star *s, void *data)
 {
     assure( s     != NULL, return 0, NULL );
     assure( s->id != NULL, return 0, NULL );
-    data = data;
+    (void)data;
     
     return sqrt(s->dmagnitude_corr * s->dmagnitude_corr +
                 s->id->dmagnitude * s->id->dmagnitude);
@@ -566,7 +566,7 @@ fors_star_get_zeropoint_err(const fors_star *s, void *data)
 bool
 fors_star_is_identified(const fors_star *s, void *data)
 {
-    data = data;
+    (void)data;
     assure( s     != NULL, return 0, NULL );
     return (s->id != NULL && s->id->trusted);
 }
