@@ -394,20 +394,21 @@ fors_frameset_print(const cpl_frameset *frames)
 {
     /* Two special cases: a NULL frame set and an empty frame set */
 
-    if (frames == NULL) {
+    if (frames == NULL)
+    {
         cpl_msg_info(cpl_func, "NULL");
     }
-    else {
-        const cpl_frame *f = NULL;
-        f = cpl_frameset_get_first_const(frames);
-        
-        if (f == NULL) {
+    else
+    {
+        if (cpl_frameset_get_size(frames) == 0)
+        {
             cpl_msg_info(cpl_func, "[Empty frame set]");
         }
-        else {
-            while(f != NULL) {
-                fors_frame_print(f);
-                f = cpl_frameset_get_next_const(frames);
+        else
+        {
+            for (int i = 0; i < cpl_frameset_get_size(frames); ++i) {
+                const cpl_frame * f = cpl_frameset_get_position_const(frames, i);
+                    fors_frame_print(f);
             }
         }
     }
