@@ -28,7 +28,6 @@
 #ifndef FORS_UTILS_H
 #define FORS_UTILS_H
 
-#include <fors_setting.h>
 #include <fors_star.h>
 
 #include <cpl.h>
@@ -126,14 +125,6 @@ do if (!(condition)) {                                      \
 
 #define fors_msg(level, ...) fors_msg_macro(level, cpl_func, __VA_ARGS__)
 
-#ifndef M_PI 
-#define M_PI 3.1415926535897932384626433832795
-#endif
-
-#ifndef M_E
-#define M_E  2.7182818284590452354
-#endif
-
 /*2 * sqrt(2 * ln(2))*/
 #define TWOSQRT2LN2 2.35482004503095
 
