@@ -673,7 +673,7 @@ Moved outside by Carlo - end */
     /* FIXME: FAP: use WCS corrected header */
     fors_dfs_save_image_err(frames, std, STANDARD_REDUCED_IMG,
                         product_header, NULL, parameters, fors_zeropoint_name, 
-                        cpl_frameset_get_position(std_frame, 0));
+                        cpl_frameset_get_position(std_frame, 0), NULL);
     assure( !cpl_error_get_code(), return, "Saving %s failed",
             STANDARD_REDUCED_IMG);
 
@@ -751,7 +751,7 @@ Moved outside by Carlo - end */
         /* FIXME: FAP: use WCS corrected header */
         fors_dfs_save_image_err(frames, std, "DEBUG",
                             product_header, NULL, parameters, fors_zeropoint_name, 
-                            cpl_frameset_get_position(std_frame, 0));
+                            cpl_frameset_get_position(std_frame, 0), NULL);
         assure( !cpl_error_get_code(), return, "Saving %s failed",
                 "DEBUG");
     }
