@@ -190,9 +190,9 @@ test_dark(void)
     /* Test results */
     {
         /* New and previous frames */
-        test( cpl_frameset_find(frames, MASTER_DARK) != NULL );
-        test( cpl_frameset_find(frames, MASTER_BIAS) != NULL );
-        test( cpl_frameset_find(frames, DARK) != NULL );
+        cpl_test( cpl_frameset_find(frames, MASTER_DARK) != NULL );
+        cpl_test( cpl_frameset_find(frames, MASTER_BIAS) != NULL );
+        cpl_test( cpl_frameset_find(frames, DARK) != NULL );
         
         master_dark = fors_image_load(
             cpl_frameset_find(frames, MASTER_DARK));
@@ -205,14 +205,14 @@ test_dark(void)
         
         /* Verify relation
            master_dark = raw_dark - master_bias */
-        test_rel( fors_image_get_mean(master_dark, NULL),
+        cpl_test_rel( fors_image_get_mean(master_dark, NULL),
                   fors_image_get_mean(raw_dark, NULL) -
                   fors_image_get_mean(master_bias, NULL) - 200, //Hardcoded overscan level
                   0.03);
 
         /* Verify that error decreased  */
         {
-            test( fors_image_get_error_mean(master_dark, NULL) /
+            cpl_test( fors_image_get_error_mean(master_dark, NULL) /
                   (fors_image_get_mean(master_dark, NULL) +
                    fors_image_get_mean(master_bias, NULL) + 200) //Hardcoded overscan level
                   <
@@ -224,57 +224,57 @@ test_dark(void)
             const char * master_dark_fname =
                     cpl_frame_get_filename(cpl_frameset_find(frames, MASTER_DARK));
 
-            test(master_dark_fname != NULL && strlen(master_dark_fname) > 0);
+            cpl_test(master_dark_fname != NULL && strlen(master_dark_fname) > 0);
 
             cpl_propertylist * list = cpl_propertylist_load(master_dark_fname, 0);
-            test(list != NULL);
-            test(cpl_error_get_code() == CPL_ERROR_NONE);
+            cpl_test(list != NULL);
+            cpl_test(cpl_error_get_code() == CPL_ERROR_NONE);
 
 
             const double raw_mean_of_means = cpl_propertylist_get_double(list,
                     "ESO QC DARK RAW MEAN MEAN");
-            test_rel(raw_mean_of_means, get_mean_from_raws(darks), 1e-10);
+            cpl_test_rel(raw_mean_of_means, get_mean_from_raws(darks), 1e-10);
 
-            test(cpl_error_get_code() == CPL_ERROR_NONE);
+            cpl_test(cpl_error_get_code() == CPL_ERROR_NONE);
             const double raw_median_of_means = cpl_propertylist_get_double(list,
                     "ESO QC DARK RAW MEAN MEDIAN");
-            test_rel(raw_median_of_means, get_median_from_raws(darks), 1e-10);
+            cpl_test_rel(raw_median_of_means, get_median_from_raws(darks), 1e-10);
 
-            test(cpl_error_get_code() == CPL_ERROR_NONE);
+            cpl_test(cpl_error_get_code() == CPL_ERROR_NONE);
             const double raw_mean_of_stddevs = cpl_propertylist_get_double(list,
                     "ESO QC DARK RAW STDEV MEAN");
-            test(cpl_error_get_code() == CPL_ERROR_NONE);
-            test_rel(raw_mean_of_stddevs, get_stddevs_from_raws(darks), 1e-10);
+            cpl_test(cpl_error_get_code() == CPL_ERROR_NONE);
+            cpl_test_rel(raw_mean_of_stddevs, get_stddevs_from_raws(darks), 1e-10);
 
             const long long raw_n_badpix = cpl_propertylist_get_long_long(list,
                         "ESO QC DARK RAW NBADPX");
-            test(cpl_error_get_code() == CPL_ERROR_NONE);
-            test(raw_n_badpix ==  number_total_of_saturated);
+            cpl_test(cpl_error_get_code() == CPL_ERROR_NONE);
+            cpl_test(raw_n_badpix ==  number_total_of_saturated);
 
             double master_median = cpl_propertylist_get_double(list,
                         "ESO QC DARK MEDIAN");
-            test(cpl_error_get_code() == CPL_ERROR_NONE);
-            test_rel(master_median, cpl_image_get_median(master_dark->data), 1e-10);
+            cpl_test(cpl_error_get_code() == CPL_ERROR_NONE);
+            cpl_test_rel(master_median, cpl_image_get_median(master_dark->data), 1e-10);
 
             double master_mean = cpl_propertylist_get_double(list,
                         "ESO QC DARK MEAN");
-            test(cpl_error_get_code() == CPL_ERROR_NONE);
-            test_rel(master_mean, cpl_image_get_mean(master_dark->data), 1e-10);
+            cpl_test(cpl_error_get_code() == CPL_ERROR_NONE);
+            cpl_test_rel(master_mean, cpl_image_get_mean(master_dark->data), 1e-10);
 
             double master_stddev = cpl_propertylist_get_double(list,
                         "ESO QC DARK STDEV");
-            test(cpl_error_get_code() == CPL_ERROR_NONE);
-            test_rel(master_stddev, cpl_image_get_stdev(master_dark->data), 1e-10);
+            cpl_test(cpl_error_get_code() == CPL_ERROR_NONE);
+            cpl_test_rel(master_stddev, cpl_image_get_stdev(master_dark->data), 1e-10);
 
             double master_min = cpl_propertylist_get_double(list,
                         "ESO QC DARK MIN");
-            test(cpl_error_get_code() == CPL_ERROR_NONE);
-            test_rel(master_min, cpl_image_get_min(master_dark->data), 1e-10);
+            cpl_test(cpl_error_get_code() == CPL_ERROR_NONE);
+            cpl_test_rel(master_min, cpl_image_get_min(master_dark->data), 1e-10);
 
             double master_max = cpl_propertylist_get_double(list,
                         "ESO QC DARK MAX");
-            test(cpl_error_get_code() == CPL_ERROR_NONE);
-            test_rel(master_max, cpl_image_get_max(master_dark->data), 1e-10);
+            cpl_test(cpl_error_get_code() == CPL_ERROR_NONE);
+            cpl_test_rel(master_max, cpl_image_get_max(master_dark->data), 1e-10);
 
             cpl_propertylist_delete(list);
         }
