@@ -428,19 +428,14 @@ static void test_dfs_proplist_add(void)
     assure( 2.0 == cpl_propertylist_get_double(list, "CRPIX2"), return,
         			"Case 3: Setter2 for list not working");
 
-    setting = fors_setting_new(frame);
-
-    setting->prescan_x = 11;
-    setting->prescan_y = 10;
-
-	fors_dfs_add_wcs(list, frame, setting);
+	fors_dfs_copy_wcs(list, frame);
 
 	assure(cpl_propertylist_get_size(list) == 8, return,
 				"Case 3: wrong length of the list");
 
-    assure( -10.0 == cpl_propertylist_get_double(list, "CRPIX1"), return,
+    assure( 1.0 == cpl_propertylist_get_double(list, "CRPIX1"), return,
     			"Case 3: add wcs + prescan correction not working (1)");
-    assure( -9.0 == cpl_propertylist_get_double(list, "CRPIX2"), return,
+    assure( 1.0 == cpl_propertylist_get_double(list, "CRPIX2"), return,
         			"Case 3: add wcs + prescan correction not working (2)");
 
 	cleanup;
