@@ -207,11 +207,11 @@ printf("  deviata a %2f %2f ------> (%2f,%2f)\n", offsetx, offsety, source->pixe
                                                (fors_star_list_func_predicate) fors_star_equal, 
                                                star);
                     
-                    test_eq( fors_star_list_size(input), 1 );
+                    cpl_test_eq( fors_star_list_size(input), 1 );
 
                     fors_star *input1 = fors_star_list_first(input);
 
-                    test( fors_std_star_equal(star->id, input1->id) );
+                    cpl_test( fors_std_star_equal(star->id, input1->id) );
 
                     fors_star_list_delete(&input, fors_star_delete);
                 }
@@ -271,7 +271,7 @@ printf("id = %d, tot = %d\n", id, tot);
              star != NULL;
              star = fors_star_list_next(stars)) {
 
-            test( star->id == NULL );
+            cpl_test( star->id == NULL );
         }
     }            
 
