@@ -107,9 +107,9 @@ test_image(void)
     saturated = fors_saturation_img_satper(image);
     
     
-    test_rel( saturated, 100 * (1 - 1.0 / (nx*ny)), 0.01 ); 
-    test_eq( nx, fors_image_get_size_x(image) );
-    test_eq( ny, fors_image_get_size_y(image) );
+    cpl_test_rel( saturated, 100 * (1 - 1.0 / (nx*ny)), 0.01 ); 
+    cpl_test_eq( nx, fors_image_get_size_x(image) );
+    cpl_test_eq( ny, fors_image_get_size_y(image) );
 
     cpl_frame_delete(frame);
     cpl_propertylist_delete(header);
@@ -148,13 +148,13 @@ test_image(void)
               4
               2
      */
-    test_eq( fors_image_get_size_x(image), 1 );
-    test_eq( fors_image_get_size_y(image), 2 );
+    cpl_test_eq( fors_image_get_size_x(image), 1 );
+    cpl_test_eq( fors_image_get_size_y(image), 2 );
 
-    test_rel( fors_image_get_min(image), 2, 0.0001 );
-    test_rel( fors_image_get_max(image), 4, 0.0001 );
-    test_rel( fors_image_get_mean(image, NULL), 3, 0.0001 );
-    test_rel( fors_image_get_stdev(image, NULL), sqrt(2), 0.0001 );
+    cpl_test_rel( fors_image_get_min(image), 2, 0.0001 );
+    cpl_test_rel( fors_image_get_max(image), 4, 0.0001 );
+    cpl_test_rel( fors_image_get_mean(image, NULL), 3, 0.0001 );
+    cpl_test_rel( fors_image_get_stdev(image, NULL), sqrt(2), 0.0001 );
 
     fors_image_delete(&image);
 
@@ -246,8 +246,8 @@ test_subtract(void)
 
     /* Check results */
     error_after = fors_image_get_error_mean(left, NULL);
-    test_rel( fors_image_get_mean(left, NULL), values*(1-0.6), 0.001);
-    test_rel( error_after, error_before*sqrt(2.0), 0.001);
+    cpl_test_rel( fors_image_get_mean(left, NULL), values*(1-0.6), 0.001);
+    cpl_test_rel( error_after, error_before*sqrt(2.0), 0.001);
     
     cleanup;
     return;
@@ -277,7 +277,7 @@ test_exponential(void)
     fors_image_exponential(image, base, dbase);
 
     /* Check results */
-    test_rel( fors_image_get_mean(image, NULL), pow(base, values), 0.001);
+    cpl_test_rel( fors_image_get_mean(image, NULL), pow(base, values), 0.001);
     
     cleanup;
     return;
@@ -323,8 +323,8 @@ test_divide(void)
     error_after =
         fors_image_get_error_mean(image, NULL) /
         fors_image_get_mean      (image, NULL);
-    test_rel( fors_image_get_mean(image, NULL), 1.0, 0.001 );
-    test_rel( error_after, error_before*sqrt(2.0), 0.001 );
+    cpl_test_rel( fors_image_get_mean(image, NULL), 1.0, 0.001 );
+    cpl_test_rel( error_after, error_before*sqrt(2.0), 0.001 );
 
     cleanup;
     return;
