@@ -69,7 +69,7 @@ test_setting(void)
 
     setting = fors_setting_new(sflat);
 
-    test_rel(setting->exposure_time, exptime, 0.001);
+    cpl_test_rel(setting->exposure_time, exptime, 0.001);
    
     cleanup;
     return;
