@@ -96,7 +96,7 @@ test_stack(void)
     ilist = fors_image_load_list(raw);
     assure( ilist != NULL, return, "Loading list failed" );
     
-    test_eq( fors_image_list_size(ilist), 3 );
+    cpl_test_eq( fors_image_list_size(ilist), 3 );
     
     /* For each stack method */
     for (i = 0; i < 2; i++) {
@@ -124,11 +124,11 @@ test_stack(void)
         /* Compare results */
         
         /* Same level */
-        test_abs( fors_image_get_mean(master, NULL), 
+        cpl_test_abs( fors_image_get_mean(master, NULL), 
                   fors_image_get_mean(fors_image_list_first_const(ilist), NULL), 1.0);
 
         /* Test that avg(sigma_i) is consistent with empirical stdev */
-        test_rel( fors_image_get_stdev(master, NULL), 
+        cpl_test_rel( fors_image_get_stdev(master, NULL), 
                   fors_image_get_error_mean(master, NULL), 
                   i == 0 ? 0.01 :
                   i == 1 ? 0.1 : 0.01);
