@@ -155,7 +155,7 @@ test_dist(void)
            are very perpendicular, so
            expect distance = sqrt(2) * shift_arcsecs 
         */
-        test_rel( fors_std_star_dist_arcsec(s, t), sqrt(2)*shift_arcsecs, 0.01 );
+        cpl_test_rel( fors_std_star_dist_arcsec(s, t), sqrt(2)*shift_arcsecs, 0.01 );
         
         fors_std_star_delete(&s);
         fors_std_star_delete(&t);
