@@ -32,6 +32,8 @@
 
 #include <cpl.h>
 
+CPL_BEGIN_DECLS
+
 cpl_frame *
 create_bias(const char *filename, const char *tag, cpl_frame_group group);
 
@@ -63,9 +65,14 @@ create_phot_table(const char *filename, const char *tag, cpl_frame_group group);
 
 cpl_frame *
 create_zeropint_header_table(const char *filename, const char *tag, cpl_frame_group group,
-		const double zp, const double zp_err);
+                             const double zp, const double zp_err);
+
+cpl_frame *
+create_illum_table(const char *filename, const char *tag, cpl_frame_group group);
 
 void
 create_standard_keys(cpl_propertylist *header, double exptime);
 
+CPL_END_DECLS
+
 #endif
