@@ -1,6 +1,6 @@
 /*
  * This file is part of the HDRL
- * Copyright (C) 2013 European Southern Observatory
+ * Copyright (C) 2013,2014 European Southern Observatory
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -33,6 +33,7 @@
 
 #include <cpl.h>
 #include <string.h>
+#include <math.h>
 
 /*----------------------------------------------------------------------------*/
 /**
@@ -52,6 +53,7 @@
 
 static void _hdrl_image_delete(hdrl_image * himg);
 static void _hdrl_image_delete_buffer(hdrl_image * himg);
+static void _hdrl_image_sync_mask(hdrl_image * himg);
 
 /* ---------------------------------------------------------------------------*/
 /**
@@ -155,6 +157,11 @@ const cpl_image * hdrl_image_get_error_const(const hdrl_image * himg)
 cpl_mask * hdrl_image_get_mask(hdrl_image * himg)
 {
     cpl_ensure(himg, CPL_ERROR_NULL_INPUT, NULL);
+    if (cpl_image_get_bpm_const(hdrl_image_get_image(himg)) == NULL) {
+        /* call adds mask, also add a mask to the errors */
+        cpl_image_get_bpm(hdrl_image_get_error(himg));
+    }
+
     return cpl_image_get_bpm(hdrl_image_get_image(himg));
 }
 
@@ -182,7 +189,8 @@ const cpl_mask * hdrl_image_get_mask_const(const hdrl_image * himg)
  */
 /* ---------------------------------------------------------------------------*/
 hdrl_image *
-hdrl_image_wrap(cpl_image * img, cpl_image * err, hdrl_free * destructor)
+hdrl_image_wrap(cpl_image * img, cpl_image * err, hdrl_free * destructor,
+                cpl_boolean sync_mask)
 {
     hdrl_image * himg;
     cpl_ensure(img, CPL_ERROR_NULL_INPUT, NULL);
@@ -203,6 +211,10 @@ hdrl_image_wrap(cpl_image * img, cpl_image * err, hdrl_free * destructor)
         himg->fp_free = (hdrl_free*)_hdrl_image_delete;
     }
 
+    if (sync_mask) {
+        _hdrl_image_sync_mask(himg);
+    }
+
     return himg;
 }
 
@@ -221,20 +233,24 @@ void hdrl_image_unwrap(hdrl_image * himg)
 
 /* ---------------------------------------------------------------------------*/
 /**
+ * @internal
  * @brief create a new hdrl_image from to existing images by copying them
  *
  * @param image  data to copy
  * @param error  errors to copy
+ * @param check_consistent check consistency
  *
  * @return hdrl_image
+ * @see hdrl_image_create
  */
 /* ---------------------------------------------------------------------------*/
-hdrl_image * hdrl_image_create(const cpl_image * image,
-                               const cpl_image * error)
+static hdrl_image * _hdrl_image_create(const cpl_image * image,
+                                       const cpl_image * error,
+                                       cpl_boolean check_consistent)
 {
     cpl_image * himage = NULL, * herror = NULL;
 
-    if (hdrl_image_check_consistent(image, error)) {
+    if (check_consistent && hdrl_image_check_consistent(image, error)) {
         return NULL;
     }
 
@@ -258,7 +274,28 @@ hdrl_image * hdrl_image_create(const cpl_image * image,
         cpl_image_accept_all(herror);
     }
 
-    return hdrl_image_wrap(himage, herror, NULL);
+    return hdrl_image_wrap(himage, herror, NULL, CPL_FALSE);
+}
+
+
+/* ---------------------------------------------------------------------------*/
+/**
+ * @brief create a new hdrl_image from to existing images by copying them
+ *
+ * @param image  data to copy
+ * @param error  errors to copy
+ *
+ * @return hdrl_image
+ *
+ * @note The bad pixel mask of the error-image (\a error) is completely
+ * ignored. The bad pixel mask associated with the passed image (\a image)
+ * becomes the only relevant bad pixel mask.
+ */
+/* ---------------------------------------------------------------------------*/
+hdrl_image * hdrl_image_create(const cpl_image * image,
+                               const cpl_image * error)
+{
+    return _hdrl_image_create(image, error, CPL_TRUE);
 }
 
 /* ---------------------------------------------------------------------------*/
@@ -282,7 +319,7 @@ hdrl_image * hdrl_image_new(cpl_size nx, cpl_size ny)
         return NULL;
     }
 
-    return hdrl_image_wrap(himage, herror, NULL);
+    return hdrl_image_wrap(himage, herror, NULL, CPL_FALSE);
 }
 
 hdrl_image *
@@ -301,7 +338,8 @@ hdrl_image_new_from_buffer(cpl_size nx, cpl_size ny, hdrl_buffer * buf)
     }
 
     return hdrl_image_wrap(himage, herror,
-                           (hdrl_free*)&_hdrl_image_delete_buffer);
+                           (hdrl_free*)&_hdrl_image_delete_buffer,
+                           CPL_FALSE);
 }
 
 /* ---------------------------------------------------------------------------*/
@@ -352,8 +390,8 @@ void hdrl_image_delete(hdrl_image * himg)
 /* ---------------------------------------------------------------------------*/
 hdrl_image * hdrl_image_duplicate(const hdrl_image * himg)
 {
-    return hdrl_image_create(hdrl_image_get_image_const(himg),
-                             hdrl_image_get_error_const(himg));
+    return _hdrl_image_create(hdrl_image_get_image_const(himg),
+                              hdrl_image_get_error_const(himg), CPL_FALSE);
 }
 
 /* ---------------------------------------------------------------------------*/
@@ -369,7 +407,10 @@ hdrl_image * hdrl_image_duplicate(const hdrl_image * himg)
 cpl_error_code hdrl_image_reject_from_mask(hdrl_image * self,
                                            const cpl_mask * map)
 {
-    return cpl_image_reject_from_mask(hdrl_image_get_image(self), map);
+    if (hdrl_image_get_mask_const(self) != map) {
+        cpl_image_reject_from_mask(hdrl_image_get_image(self), map);
+    }
+    return cpl_image_reject_from_mask(hdrl_image_get_error(self), map);
 }
 
 
@@ -386,7 +427,8 @@ cpl_error_code hdrl_image_reject_from_mask(hdrl_image * self,
 cpl_error_code hdrl_image_reject(hdrl_image * self,
                                  cpl_size xpos, cpl_size ypos)
 {
-    return cpl_image_reject(hdrl_image_get_image(self), xpos, ypos);
+    cpl_image_reject(hdrl_image_get_image(self), xpos, ypos);
+    return cpl_image_reject(hdrl_image_get_error(self), xpos, ypos);
 }
 
 
@@ -438,6 +480,39 @@ cpl_error_code hdrl_image_reject_value(hdrl_image * self, cpl_value mode)
 }
 
 
+/* ---------------------------------------------------------------------------*/
+/**
+ * @brief mark pixel as good
+ *
+ * @param self          image
+ * @param xpos          x coordinate (FITS CONVENTION)
+ * @param ypos          y coordinate (FITS CONVENTION)
+ * @see cpl_image_accept
+ */
+/* ---------------------------------------------------------------------------*/
+cpl_error_code hdrl_image_accept(hdrl_image * self,
+                                 cpl_size xpos, cpl_size ypos)
+{
+    cpl_image_accept(hdrl_image_get_image(self), xpos, ypos);
+    return cpl_image_accept(hdrl_image_get_error(self), xpos, ypos);
+}
+
+/* ---------------------------------------------------------------------------*/
+/**
+ * @brief Accept all pixels in an image
+ *
+ * @param self input image
+ * @see cpl_image_accept_all
+ */
+/* ---------------------------------------------------------------------------*/
+cpl_error_code hdrl_image_accept_all(hdrl_image * self)
+{
+    cpl_image_accept_all(hdrl_image_get_image(self));
+    cpl_image_accept_all(hdrl_image_get_error(self));
+    return cpl_error_get_code();
+}
+
+
 /* ---------------------------------------------------------------------------*/
 /**
  * @brief return size of X dimension of image
@@ -475,27 +550,31 @@ cpl_size hdrl_image_get_size_y(const hdrl_image * self)
  * @param self          image
  * @param xpos          x coordinate (FITS CONVENTION)
  * @param ypos          y coordinate (FITS CONVENTION)
- * @param error         hdrl_error_t pointer to store error in, may be NULL
  * @param pis_rejected  int pointer to store if pixel is bad, may be NULL
  *
  * @return data value of the pixel
  * @see cpl_image_get
  */
 /* ---------------------------------------------------------------------------*/
-hdrl_data_t hdrl_image_get_pixel(const hdrl_image * self,
-                                 cpl_size xpos, cpl_size ypos,
-                                 hdrl_error_t * error, int * pis_rejected)
+hdrl_value hdrl_image_get_pixel(const hdrl_image * self,
+                                cpl_size xpos, cpl_size ypos,
+                                int * pis_rejected)
 {
     int d;
-    double v = cpl_image_get(hdrl_image_get_image_const(self), xpos, ypos, &d);
+    hdrl_value v;
+    v.data = cpl_image_get(hdrl_image_get_image_const(self), xpos, ypos, &d);
 
     /* NULL allowed, different than CPL */
     if (pis_rejected) {
         *pis_rejected = d;
     }
-
-    if (error) {
-        *error = cpl_image_get(hdrl_image_get_error_const(self), xpos, ypos, &d);
+    if (d) {
+        v.data = NAN;
+        v.error = NAN;
+    }
+    else {
+        v.error = cpl_image_get(hdrl_image_get_error_const(self),
+                                xpos, ypos, &d);
     }
 
     return v;
@@ -510,20 +589,20 @@ hdrl_data_t hdrl_image_get_pixel(const hdrl_image * self,
  * @param xpos          x coordinate (FITS CONVENTION)
  * @param ypos          y coordinate (FITS CONVENTION)
  * @param value         data value to set
- * @param error         error of value (>= 0)
  */
 /* ---------------------------------------------------------------------------*/
 cpl_error_code hdrl_image_set_pixel(hdrl_image * self,
                                     cpl_size xpos, cpl_size ypos,
-                                    hdrl_data_t value, hdrl_error_t error) 
+                                    hdrl_value value)
 {
-    cpl_ensure_code(error >= 0, CPL_ERROR_ILLEGAL_INPUT);
+    /* nan may be used as a bad pixel value */
+    cpl_ensure_code(value.error >= 0 || isnan(value.error), CPL_ERROR_ILLEGAL_INPUT);
 
-    if (cpl_image_set(hdrl_image_get_image(self), xpos, ypos, value)) {
+    if (cpl_image_set(hdrl_image_get_image(self), xpos, ypos, value.data)) {
         return cpl_error_get_code();
     }
 
-    return cpl_image_set(hdrl_image_get_error(self), xpos, ypos, error);
+    return cpl_image_set(hdrl_image_get_error(self), xpos, ypos, value.error);
 }
 
 
@@ -568,7 +647,7 @@ hdrl_image * hdrl_image_extract(
         return NULL;
     }
 
-    return hdrl_image_wrap(img, err, NULL);
+    return hdrl_image_wrap(img, err, NULL, CPL_FALSE);
 }
 
 
@@ -622,7 +701,7 @@ cpl_error_code hdrl_image_copy(hdrl_image * dst, const hdrl_image * src,
 /**
   @brief    Copy cpl images into an hdrl image
   @param    self    the image in which the cpl images are inserted
-  @param    image   the inserted image, may be NULL
+  @param    image   the inserted image
   @param    error   the inserted error, may be NULL
   @param    xpos    the x pixel position in im1 where the lower left pixel of
                     im2 should go (from 1 to the x size of im1)
@@ -639,12 +718,89 @@ cpl_error_code hdrl_image_insert(hdrl_image * self,
                                  cpl_size xpos, cpl_size ypos)
 {
     cpl_ensure_code(self, CPL_ERROR_NULL_INPUT);
-    if (image)
-        cpl_image_copy(hdrl_image_get_image(self), image, xpos, ypos);
-    if (error)
+    cpl_ensure_code(image, CPL_ERROR_NULL_INPUT);
+    cpl_image_copy(hdrl_image_get_image(self), image, xpos, ypos);
+    if (error) {
         cpl_image_copy(hdrl_image_get_error(self), error, xpos, ypos);
+    }
+    /* sync error mask */
+    if (cpl_image_get_bpm_const(image)) {
+        const cpl_mask * msrc = cpl_image_get_bpm_const(image);
+        cpl_mask * mdst = cpl_image_get_bpm(hdrl_image_get_error(self));
+        cpl_mask_copy(mdst, msrc, xpos, ypos);
+    }
 
     return cpl_error_get_code();
 }
 
+
+/* ---------------------------------------------------------------------------*/
+/**
+ * @brief synchronize mask
+ */
+/* ---------------------------------------------------------------------------*/
+
+static void _hdrl_image_sync_mask(hdrl_image * himg)
+{
+    const cpl_mask * m = hdrl_image_get_mask_const(himg);
+    if (m) {
+        hdrl_image_reject_from_mask(himg, m);
+    }
+    else {
+        cpl_image_accept_all(hdrl_image_get_error(himg));
+    }
+}
+
+/*----------------------------------------------------------------------------*/
+/**
+  @ingroup hdrl_image
+  @brief    Dump structural information of a HDRL image
+  @param    himg    Image to dump
+  @param    stream  Output stream, accepts @c stdout or @c stderr
+  @return   CPL_ERROR_NONE or the relevant cpl-error-code on error
+
+  Possible cpl-error-code set in this function:
+  - CPL_ERROR_NULL_INPUT if an input pointer is NULL
+  - CPL_ERROR_FILE_IO if a write operation fails
+ */
+/*----------------------------------------------------------------------------*/
+cpl_error_code hdrl_image_dump_structure(
+        const hdrl_image    *   himg,
+        FILE                *   stream)
+{
+    return cpl_image_dump_structure(hdrl_image_get_image_const(himg), stream);
+}
+
+/*----------------------------------------------------------------------------*/
+/**
+  @ingroup hdrl_image
+  @brief    Dump pixel values in a HDRL image
+  @param    himg    Image to dump
+  @param    llx     Lower left x position (FITS convention, 1 for leftmost)
+  @param    lly     Lower left y position (FITS convention, 1 for lowest)
+  @param    urx     Specifies the window position
+  @param    ury     Specifies the window position
+  @param    stream  Output stream, accepts @c stdout or @c stderr
+  @return   CPL_ERROR_NONE or the relevant cpl-error-code on error
+
+  Possible cpl-error-code set in this function:
+  - CPL_ERROR_NULL_INPUT if an input pointer is NULL
+  - CPL_ERROR_FILE_IO if a write operation fails
+  - CPL_ERROR_ACCESS_OUT_OF_RANGE if the defined window is not in the image
+  - CPL_ERROR_ILLEGAL_INPUT if the window definition is wrong (e.g llx > urx)
+ */
+/*----------------------------------------------------------------------------*/
+cpl_error_code hdrl_image_dump_window(
+        const hdrl_image    *   himg,
+        cpl_size                llx,
+        cpl_size                lly,
+        cpl_size                urx,
+        cpl_size                ury,
+        FILE *                  stream)
+{
+    return cpl_image_dump_window(hdrl_image_get_image_const(himg),
+                    llx, lly, urx, ury, stream);
+
+}
+
 /**@}*/
