@@ -39,8 +39,8 @@
  -----------------------------------------------------------------------------*/
 
 static cpl_error_code hdrl_sort_double_pairs(cpl_vector *, cpl_vector *) ;
-static long get_lower_bound_d(double * vec, long n, double val);
-static long get_upper_bound_d(double * vec, long n, double val);
+static long get_lower_bound_d(double * vec, long count, double val);
+static long get_upper_bound_d(double * vec, long count, double val);
 static long get_lower_bound(cpl_vector * vec, double val);
 static long get_upper_bound(cpl_vector * vec, double val);
 
@@ -71,12 +71,17 @@ static long get_upper_bound(cpl_vector * vec, double val);
  */
 /* ---------------------------------------------------------------------------*/
 cpl_parameterlist * hdrl_sigclip_parameter_create_parlist(
-        const char              *   base_context,
-        const char              *   prefix,
-        const hdrl_parameter    *   defaults)
+        const char           *base_context,
+        const char           *prefix,
+        const hdrl_parameter *defaults)
 {
-    cpl_ensure(base_context && prefix && defaults, CPL_ERROR_NULL_INPUT, NULL);
-    cpl_parameterlist * parlist = cpl_parameterlist_new();
+	cpl_ensure(base_context && prefix && defaults,
+			CPL_ERROR_NULL_INPUT, NULL);
+
+    cpl_ensure(hdrl_collapse_parameter_is_sigclip(defaults),
+    		CPL_ERROR_INCOMPATIBLE_INPUT, NULL);
+
+    cpl_parameterlist *parlist = cpl_parameterlist_new();
 
     /* --prefix.kappa-low */
     hdrl_setup_vparameter(parlist, prefix, ".", "",
@@ -119,11 +124,16 @@ cpl_parameterlist * hdrl_sigclip_parameter_create_parlist(
  */
 /* ---------------------------------------------------------------------------*/
 cpl_parameterlist * hdrl_minmax_parameter_create_parlist(
-        const char              *   base_context,
-        const char              *   prefix,
-        const hdrl_parameter    *   defaults)
+        const char           *base_context,
+        const char           *prefix,
+        const hdrl_parameter *defaults)
 {
-    cpl_ensure(base_context && prefix && defaults, CPL_ERROR_NULL_INPUT, NULL);
+    cpl_ensure(base_context && prefix && defaults,
+    		CPL_ERROR_NULL_INPUT, NULL);
+
+    cpl_ensure(hdrl_collapse_parameter_is_minmax(defaults),
+    		CPL_ERROR_INCOMPATIBLE_INPUT, NULL);
+
     cpl_parameterlist * parlist = cpl_parameterlist_new();
 
     /* --prefix.nlow */
@@ -354,8 +364,8 @@ cpl_error_code hdrl_minmax_clip_image(
  */
 /*----------------------------------------------------------------------------*/
 cpl_error_code hdrl_minmax_clip(
-                const cpl_vector  * vec,
-                const cpl_vector  * vec_err,
+                cpl_vector        * vec,
+                cpl_vector        * vec_err,
                 const double        nlow,
                 const double        nhigh,
                 cpl_boolean         inplace,
@@ -403,26 +413,25 @@ cpl_error_code hdrl_minmax_clip(
                      return CPL_ERROR_INCOMPATIBLE_INPUT, "nlow and nhigh must "
                                      "be strictly positive");
 
-    if (inplace) {
-        vec_image = (cpl_vector *)vec;
-        vec_image_err = (cpl_vector *)vec_err;
-    }
-    else {
-        vec_image = cpl_vector_duplicate(vec);
-        vec_image_err = cpl_vector_duplicate(vec_err);
-    }
-    vec_size = cpl_vector_get_size(vec_image);
+    vec_size = cpl_vector_get_size(vec);
 
     /* Nothing to do if only one data point */
     if(vec_size <= (nlow_int+nhigh_int)) {
         *mean_mm=NAN;
         *mean_mm_err=NAN;
         *naccepted=0;
-        cpl_vector_delete(vec_image);
-        cpl_vector_delete(vec_image_err);
         return cpl_error_get_code();
     }
 
+    if (inplace) {
+        vec_image = vec;
+        vec_image_err = vec_err;
+    }
+    else {
+        vec_image = cpl_vector_duplicate(vec);
+        vec_image_err = cpl_vector_duplicate(vec_err);
+    }
+
     hdrl_sort_double_pairs(vec_image, vec_image_err);
 
     trunc_size = (vec_size - nhigh_int) - nlow_int;
@@ -575,14 +584,14 @@ cpl_error_code hdrl_kappa_sigma_clip_image(
  * @param val upper bound to check
  */
 /* ---------------------------------------------------------------------------*/
-static long get_upper_bound_d(double * d, long count, double val)
+static long get_upper_bound_d(double * vec, long count, double val)
 {
     long first = 0;
     while (count > 0)
     {
         long step = count / 2;
         long it = first + step;
-        if (!(val < d[it])) {
+        if (!(val < vec[it])) {
             first = it + 1;
             count -= step + 1;
         }
@@ -615,14 +624,14 @@ static long get_upper_bound(cpl_vector * vec, double val)
  * @param val upper bound to check
  */
 /* ---------------------------------------------------------------------------*/
-static long get_lower_bound_d(double * d, long count, double val)
+static long get_lower_bound_d(double * vec, long count, double val)
 {
     long first = 0;
     while (count > 0)
     {
         long step = count / 2;
         long it = first + step;
-        if (d[it] < val) {
+        if (vec[it] < val) {
             first = it + 1;
             count -= step + 1;
         }
@@ -726,8 +735,8 @@ static void get_mean_err(const double * d, const double * e, long count,
  */
 /*----------------------------------------------------------------------------*/
 cpl_error_code hdrl_kappa_sigma_clip(
-        const cpl_vector  * vec,
-        const cpl_vector  * vec_err,
+        cpl_vector        * vec,
+        cpl_vector        * vec_err,
         const double        kappa_low,
         const double        kappa_high,
         const int           iter,
@@ -767,8 +776,8 @@ cpl_error_code hdrl_kappa_sigma_clip(
                      "iter must be larger than 0");
 
     if (inplace) {
-        vec_image = (cpl_vector *)vec;
-        vec_image_err = (cpl_vector *)vec_err;
+        vec_image = vec;
+        vec_image_err = vec_err;
     }
     else {
         vec_image = cpl_vector_duplicate(vec);
