@@ -25,7 +25,9 @@
                                    Includes
 -----------------------------------------------------------------------------*/
 /* for j1 */
+#if !defined(_XOPEN_SOURCE) || (_XOPEN_SOURCE - 0) < 600
 #define _XOPEN_SOURCE 600
+#endif
 
 #include "hdrl_strehl.h"
 #include "hdrl_image.h"
@@ -122,7 +124,7 @@ hdrl_strehl_parameter_verify(const hdrl_parameter    *   param)
                      CPL_ERROR_ILLEGAL_INPUT, return CPL_ERROR_ILLEGAL_INPUT,
                                      "Expected Strehl parameter") ;
 
-    const hdrl_strehl_parameter * param_loc = (hdrl_strehl_parameter *)param ;
+    const hdrl_strehl_parameter * param_loc = (const hdrl_strehl_parameter *)param ;
 
     cpl_error_ensure(param_loc->wavelength >= 0, CPL_ERROR_ILLEGAL_INPUT,
                      return CPL_ERROR_ILLEGAL_INPUT, "wavelength must be >=0");
@@ -232,7 +234,7 @@ double hdrl_strehl_parameter_get_wavelength(
         const hdrl_parameter * p)
 {
     cpl_ensure(p, CPL_ERROR_NULL_INPUT, -1.0);
-    return ((hdrl_strehl_parameter *)p)->wavelength;
+    return p != NULL ? ((const hdrl_strehl_parameter *)p)->wavelength : 0.;
 }
 
 /*----------------------------------------------------------------------------*/
@@ -246,7 +248,7 @@ double hdrl_strehl_parameter_get_m1(
         const hdrl_parameter * p)
 {
     cpl_ensure(p, CPL_ERROR_NULL_INPUT, -1.0);
-    return ((hdrl_strehl_parameter *)p)->m1;
+    return p != NULL ? ((const hdrl_strehl_parameter *)p)->m1 : 0.;
 }
 
 /*----------------------------------------------------------------------------*/
@@ -260,7 +262,7 @@ double hdrl_strehl_parameter_get_m2(
         const hdrl_parameter * p)
 {
     cpl_ensure(p, CPL_ERROR_NULL_INPUT, -1.0);
-    return ((hdrl_strehl_parameter *)p)->m2;
+    return p != NULL ? ((const hdrl_strehl_parameter *)p)->m2 : 0.;
 }
 
 /*----------------------------------------------------------------------------*/
@@ -274,7 +276,7 @@ double hdrl_strehl_parameter_get_pixel_scale_x(
         const hdrl_parameter * p)
 {
     cpl_ensure(p, CPL_ERROR_NULL_INPUT, -1.0);
-    return ((hdrl_strehl_parameter *)p)->pixel_scale_x;
+    return p != NULL ? ((const hdrl_strehl_parameter *)p)->pixel_scale_x : 0.;
 }
 
 /*----------------------------------------------------------------------------*/
@@ -288,7 +290,7 @@ double hdrl_strehl_parameter_get_pixel_scale_y(
         const hdrl_parameter * p)
 {
     cpl_ensure(p, CPL_ERROR_NULL_INPUT, -1.0);
-    return ((hdrl_strehl_parameter *)p)->pixel_scale_y;
+    return p != NULL ? ((const hdrl_strehl_parameter *)p)->pixel_scale_y : 0.;
 }
 
 /*----------------------------------------------------------------------------*/
@@ -302,7 +304,7 @@ double hdrl_strehl_parameter_get_flux_radius(
         const hdrl_parameter * p)
 {
     cpl_ensure(p, CPL_ERROR_NULL_INPUT, -1.0);
-    return ((hdrl_strehl_parameter *)p)->flux_radius;
+    return p != NULL ? ((const hdrl_strehl_parameter *)p)->flux_radius : 0.;
 }
 
 /*----------------------------------------------------------------------------*/
@@ -316,7 +318,7 @@ double hdrl_strehl_parameter_get_bkg_radius_low(
         const hdrl_parameter * p)
 {
     cpl_ensure(p, CPL_ERROR_NULL_INPUT, -1.0);
-    return ((hdrl_strehl_parameter *)p)->bkg_radius_low;
+    return p != NULL ? ((const hdrl_strehl_parameter *)p)->bkg_radius_low : 0.;
 }
 
 /*----------------------------------------------------------------------------*/
@@ -330,7 +332,7 @@ double hdrl_strehl_parameter_get_bkg_radius_high(
         const hdrl_parameter * p)
 {
     cpl_ensure(p, CPL_ERROR_NULL_INPUT, -1.0);
-    return ((hdrl_strehl_parameter *)p)->bkg_radius_high;
+    return p != NULL ? ((const hdrl_strehl_parameter *)p)->bkg_radius_high : 0.;
 }
 
 /*----------------------------------------------------------------------------*/
@@ -356,13 +358,18 @@ double hdrl_strehl_parameter_get_bkg_radius_high(
  */
 /*----------------------------------------------------------------------------*/
 cpl_parameterlist * hdrl_strehl_parameter_create_parlist(
-        const char      *   base_context,
-        const char      *   prefix,
-        hdrl_parameter  *   par)
+        const char     *base_context,
+        const char     *prefix,
+        hdrl_parameter *par)
 {
 
-    cpl_ensure(prefix && base_context, CPL_ERROR_NULL_INPUT, NULL);
-    cpl_parameterlist   *   parlist = cpl_parameterlist_new();
+    cpl_ensure(prefix && base_context && par,
+    		CPL_ERROR_NULL_INPUT, NULL);
+
+    cpl_ensure(hdrl_strehl_parameter_check(par),
+    		CPL_ERROR_INCOMPATIBLE_INPUT, NULL);
+
+    cpl_parameterlist *parlist = cpl_parameterlist_new();
 
     /* --prefix.wavelength */
     hdrl_setup_vparameter(parlist, prefix, ".", "", "wavelength", base_context,
@@ -414,7 +421,6 @@ cpl_parameterlist * hdrl_strehl_parameter_create_parlist(
         return NULL;
     }
 
-
     return parlist;
 }
 
@@ -444,8 +450,8 @@ hdrl_parameter * hdrl_strehl_parameter_parse_parlist(
         const char              *   prefix)
 {
     cpl_ensure(prefix && parlist, CPL_ERROR_NULL_INPUT, NULL);
-    char                *   name ;
-    const cpl_parameter *   par = NULL;
+    char                *   name;
+    const cpl_parameter *   par;
     double                  wavelength, m1, m2, pixel_scale_x, pixel_scale_y,
                             flux_radius, bkg_radius_low,bkg_radius_high;
 
@@ -514,6 +520,28 @@ hdrl_parameter * hdrl_strehl_parameter_parse_parlist(
 
 /** @cond PRIVATE */
 
+/* ---------------------------------------------------------------------------*/
+/**
+ * @internal
+ * @brief mask where mask is valid
+ * @param himg  hdrl image
+ * @param mask mask defining where to find max
+ * @return max and its error
+ */
+/* ---------------------------------------------------------------------------*/
+static hdrl_value
+hdrl_image_max_where(const hdrl_image * himg, cpl_mask * mask)
+{
+    hdrl_image * tmpimg = hdrl_image_duplicate(himg);
+    cpl_size px, py;
+    hdrl_value mx;
+    hdrl_image_reject_from_mask(tmpimg, mask);
+    cpl_image_get_maxpos(hdrl_image_get_image(tmpimg), &px, &py);
+    mx = hdrl_image_get_pixel(tmpimg, px, py, NULL);
+    hdrl_image_delete(tmpimg);
+    return mx;
+}
+
 /* ---------------------------------------------------------------------------*/
 /**
  * @internal
@@ -569,7 +597,7 @@ hdrl_image_stdev_where(const hdrl_image * himg, cpl_mask * mask)
     hdrl_image * tmpimg = hdrl_image_duplicate(himg);
     double mad;
     hdrl_image_reject_from_mask(tmpimg, mask);
-    cpl_image_get_mad(hdrl_image_get_image_const(himg), &mad);
+    cpl_image_get_mad(hdrl_image_get_image_const(tmpimg), &mad);
     hdrl_image_delete(tmpimg);
     return mad * CPL_MATH_STD_MAD;
 }
@@ -630,7 +658,8 @@ compute_psf(double lam, double m1, double m2,
     double ylow = -((ny - 1) * pixscale_y / 2) - centery;
     double step_x = (xhigh - xlow) / (nx - 1);
     double step_y = (yhigh - ylow) / (ny - 1);
-HDRL_OMP(omp parallel for)
+
+    HDRL_OMP(omp parallel for)
     for (size_t iy = 0; iy < ny; iy++) {
         double y = iy == ny - 1 ? yhigh : ylow + iy * step_y;
         for (size_t ix = 0; ix < nx; ix++) {
@@ -833,7 +862,7 @@ gaussian_maxpos(const cpl_image * self,
         const double M_x = cpl_array_get_double(gauss_parameters, 3, NULL);
         const double M_y = cpl_array_get_double(gauss_parameters, 4, NULL);
 
-        valfit = cpl_gaussian_eval_2d(gauss_parameters, M_x, M_y);
+        valfit = hcpl_gaussian_eval_2d(gauss_parameters, M_x, M_y);
 
         if (!cpl_errorstate_is_equal(prestate)) {
             code = cpl_error_get_code();
@@ -941,7 +970,7 @@ static inline cpl_image * hdrl_rebin(cpl_image * img, size_t sampling)
     }
     return n;
 }
-
+#if 0
 /* ---------------------------------------------------------------------------*/
 /**
  * @brief compute encircled energy of psf
@@ -982,7 +1011,7 @@ compute_psf_flux(double lam, double m1, double m2, double r)
        neglect the contribute from integral term: -2*e*integral(j1*j1*2/v dv) */
     return E;
 }
-
+#endif
 
 /* ---------------------------------------------------------------------------*/
 /**
@@ -1084,11 +1113,8 @@ compute_strehl2(const hdrl_image * himg, double lam,
     }
     
     /* computes ratio peak/flux over the observed PSF standard */
-    cpl_size px, py;
-    cpl_image_get_maxpos(img, &px, &py);
-    hdrl_value ipeak = hdrl_image_get_pixel(himg, px, py, NULL);
-    cpl_mask  * im =
-        strehl_disk_mask(img, px - 1, py - 1, radius_pix);
+    cpl_mask  * im = strehl_disk_mask(img, peak_x, peak_y, radius_pix);
+    hdrl_value ipeak = hdrl_image_max_where(himg, im);
     cpl_msg_debug(cpl_func, "Computing flux on %d pixel radius, total pixels %ld",
                   (int)(radius_pix),
                   (long)(cpl_mask_get_size_x(im) * cpl_mask_get_size_y(im) -
@@ -1131,6 +1157,8 @@ compute_strehl2(const hdrl_image * himg, double lam,
     r.star_peak = ipeak;
     r.star_flux = iflux;
     r.star_background = (hdrl_value){0, 0};
+    /* TODO:
+     * error on negative flux, error on disk max position != fit position */
     return r;
 }
 
@@ -1228,7 +1256,7 @@ compute_strehl(const hdrl_image * himg_, double lam,
             cpl_error_set_message(cpl_func, CPL_ERROR_ILLEGAL_INPUT,
                           "No valid pixels in background");
             cpl_mask_delete(low);
-            hdrl_image_delete(himg);
+            cpl_mask_delete(high);
             goto error;
         }
 
@@ -1274,7 +1302,7 @@ error:
  * The raw image is assumed to be pre-processed to remove the instrument
  * signatures (bad pixels, etc.) and the natural noise sources (sky background,
  * etc.). Nethertheless this function allows also the user to correct a residual
- * background by setting the parameters \e bkg_radius\_low, \e bkg_radius_high.
+ * background by setting the parameters \e bkg_radius_low, \e bkg_radius_high.
  * The PSF is identified and its integrated flux (controlled by the parameter
  * \e flux_radius) is normalized to 1. The
  * PSF baricenter is computed and used to generate the ideal PSF (with
