@@ -62,6 +62,18 @@ typedef enum {
     HDRL_UNDEFINED_AXIS
 } hdrl_direction;
 
+/*----------------------------------------------------------------------------*/
+/**
+  @enum hdrl_airmass_approx
+  @brief Define the kind of airmass approximation
+ */
+/*----------------------------------------------------------------------------*/
+typedef enum {
+  HDRL_AIRMASS_APPROX_HARDIE = 1,		/* Hardie(1962)          */
+  HDRL_AIRMASS_APPROX_YOUNG_IRVINE,		/* Young & Irvine (1967) */
+  HDRL_AIRMASS_APPROX_YOUNG				/* Young(1994)           */
+} hdrl_airmass_approx;
+
 /*-----------------------------------------------------------------------------
                             Functions prototypes
  -----------------------------------------------------------------------------*/
@@ -86,6 +98,9 @@ cpl_parameterlist * hdrl_rect_region_parameter_create_parlist(const char *,
         const char *, const char *, const hdrl_parameter *) ;
 hdrl_parameter * hdrl_rect_region_parameter_parse_parlist(
         const cpl_parameterlist *, const char *, const char *) ;
+cpl_boolean hdrl_is_strictly_monotonic_increasing(const double * x, cpl_size l);
+void hdrl_sort_on_x(double * x, double * y1, double * y2,
+        const cpl_size sample_len, const cpl_boolean sort_decreasing);
 
 /*-----------------------------------------------------------------------------
   Experimental declarations - can be used, but no guarantees on api stability
@@ -97,11 +112,11 @@ typedef enum {
 } hdrl_scale_type;
 
 cpl_error_code
-hdrl_normalize_imagelist_by_vector(const cpl_vector * vector,
-                                   const cpl_vector * evector,
-                                   hdrl_scale_type scale_type,
-                                   cpl_imagelist * data,
-                                   cpl_imagelist * errors);
+hdrl_normalize_imagelist_by_vector(const cpl_vector      * scale,
+                                   const cpl_vector      * scale_e,
+								   const hdrl_scale_type   scale_type,
+                                   cpl_imagelist         * data,
+                                   cpl_imagelist         * errors);
 
 cpl_error_code
 hdrl_normalize_imagelist_by_imagelist(const cpl_imagelist * scale,
@@ -121,11 +136,38 @@ hdrl_wcs_convert(const cpl_wcs *wcs, const cpl_matrix *from,
                  cpl_wcs_trans_mode transform);
 #endif
 
+/* --------------- *
+ * Airmass funcion *
+ * --------------- */
+hdrl_value hdrl_utils_airmass(
+	hdrl_value aRA, hdrl_value aDEC, hdrl_value aLST,
+	hdrl_value aExptime, hdrl_value aLatitude,
+	hdrl_airmass_approx type);
+
+/* must not be followed by a semicolon!
+ * gcc on mac has omp but it doesn't work for nontrivial cases as libc lacks
+ * alloca */
+#if defined (_OPENMP) && !defined( __APPLE__)
+  #define HDRL_OMP(x) _Pragma (#x)
+#else
+  #define HDRL_OMP(x)
+#endif
+
 /*-----------------------------------------------------------------------------
              Private declarations - must not be used outside of hdrl
  -----------------------------------------------------------------------------*/
 #ifdef HDRL_USE_PRIVATE
 
+/* Private functions for airmass calculations */
+hdrl_value hdrl_get_zenith_distance(
+	hdrl_value aHourAngle, hdrl_value aDelta, hdrl_value aLatitude);
+
+hdrl_value hdrl_get_airmass_hardie(      hdrl_value hvaSecZ);
+hdrl_value hdrl_get_airmass_youngirvine( hdrl_value hvaSecZ);
+hdrl_value hdrl_get_airmass_young(       hdrl_value hvaCosZt);
+/* ---------------------- */
+
+
 cpl_image *
 hdrl_medianfilter_image_grid(const cpl_image * ima, cpl_matrix * x, cpl_matrix * y,
                              cpl_size  filtersize_x, cpl_size filtersize_y);
@@ -141,18 +183,10 @@ cpl_image * hdrl_legendre_to_image(cpl_matrix * coeffs, int order_x,
 
 int hdrl_check_maskequality(const cpl_mask * mask1, const cpl_mask * mask2);
 
-/* must not be followed by a semicolon!
- * gcc on mac has omp but it doesn't work for nontrivial cases as libc lacks
- * alloca */
-#if defined (_OPENMP) && !defined( __APPLE__)
-#define HDRL_OMP(x) _Pragma (#x)
-#else
-#define HDRL_OMP(x)
-#endif
-
 typedef struct hdrl_vector_cache_ hdrl_vector_cache;
 
-hdrl_vector_cache * hdrl_vector_cache_new(cpl_size max_depth, cpl_size exp_width);
+hdrl_vector_cache * hdrl_vector_cache_new(cpl_size max_cached_size,
+		                                  cpl_size ncached_entries);
 void hdrl_vector_cache_delete(hdrl_vector_cache * cache);
 cpl_vector * hdrl_cplvector_new_from_cache(hdrl_vector_cache * cache, cpl_size sz);
 void hdrl_cplvector_delete_to_cache(hdrl_vector_cache * cache, cpl_vector * v);
@@ -183,7 +217,7 @@ do { \
 
 cpl_vector * hdrl_image_to_vector(const cpl_image * source, const
         cpl_mask * bpm);
-cpl_vector * hdrl_imagelist_to_vector(const cpl_imagelist * source, 
+cpl_vector * hdrl_imagelist_to_vector(const cpl_imagelist * list,
         const cpl_size x, const cpl_size y);
 cpl_error_code hdrl_imagelist_to_vector_row(const cpl_imagelist * list,
                                             const cpl_size y,
@@ -202,6 +236,10 @@ hdrl_parallel_filter_image(const cpl_image * img,
                            const cpl_filter_mode mode);
 
 cpl_mask * hcpl_image_set_bpm(cpl_image * self, cpl_mask * bpm) ;
+double hcpl_vector_get_mad_window(cpl_vector * vec,
+                                  cpl_size llx,
+                                  cpl_size urx,
+                                  double * sigma);
 double hcpl_gaussian_eval_2d(const cpl_array * self, double x, double y);
 
 static inline int hdrl_int_is_power_of_two(unsigned long long x)
@@ -245,6 +283,16 @@ static inline hdrl_data_t * hdrl_get_image_data(cpl_image * image)
 #endif
 }
 
+static inline cpl_error_code
+hdrl_wrap_table(cpl_table * tb, hdrl_data_t * data, const char * name)
+{
+#if HDRL_SIZEOF_DATA == 8
+    return cpl_table_wrap_double(tb, data, name);
+#else
+    return cpl_table_wrap_float(tb, data, name);
+#endif
+}
+
 static inline hdrl_error_t * hdrl_get_image_error(cpl_image * image)
 {
 #if HDRL_SIZEOF_ERROR == 8
