@@ -1,5 +1,4 @@
-/* $Id: hdrl_overscan-test.c,v 1.16 2013-10-23 09:13:56 jtaylor Exp $
- *
+/* 
  * This file is part of the HDRL
  * Copyright (C) 2012,2013 European Southern Observatory
  *
@@ -18,13 +17,6 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-/*
- * $Author: jtaylor $
- * $Date: 2013-10-23 09:13:56 $
- * $Revision: 1.16 $
- * $Name: not supported by cvs2svn $
- */
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -51,33 +43,84 @@
 typedef enum {
     HDRL_OSCAN_COLLAPSE_TEST_MEAN,
     HDRL_OSCAN_COLLAPSE_TEST_MEDIAN,
-    HDRL_OSCAN_COLLAPSE_TEST_SIGCLIP
+	HDRL_OSCAN_COLLAPSE_TEST_WEIGHTED_MEAN,
+    HDRL_OSCAN_COLLAPSE_TEST_SIGCLIP,
+    HDRL_OSCAN_COLLAPSE_TEST_MINMAX
 } hdrl_oscan_collapse_test ;
 
 /*----------------------------------------------------------------------------*/
 /**
- * @defgroup hdrl_overscan_test Testing of the HDRL Overscan module
+  @defgroup hdrl_overscan_test  Testing of the HDRL Overscan module
  */
 /*----------------------------------------------------------------------------*/
 
+void test_parlist(void)
+{
+    /* parameter parsing smoketest */
+    hdrl_parameter * hpar;
+    hdrl_parameter * rect_region_def =
+        hdrl_rect_region_parameter_create(1, 1, 20, 20);
+    hdrl_parameter * sigclip_def =
+        hdrl_collapse_sigclip_parameter_create(3., 3., 5);
+    hdrl_parameter * minmax_def =
+        hdrl_collapse_minmax_parameter_create(2., 3.);
+    cpl_parameterlist * pos = hdrl_overscan_parameter_create_parlist(
+                "RECIPE", "oscan", "alongX", 10, 10., rect_region_def,
+                "MINMAX", sigclip_def, minmax_def);
+    hdrl_parameter_delete(sigclip_def);
+    hdrl_parameter_delete(minmax_def);
+    hdrl_parameter_delete(rect_region_def);
+    cpl_test_error(CPL_ERROR_NONE);
+    cpl_test_eq(cpl_parameterlist_get_size(pos), 13);
+
+    hpar = hdrl_overscan_parameter_parse_parlist(pos, "RECIPE.invalid");
+    cpl_test_null(hpar);
+    cpl_test_error(CPL_ERROR_DATA_NOT_FOUND);
+
+    hpar = hdrl_overscan_parameter_parse_parlist(pos, "RECIPE.oscan");
+    cpl_parameterlist_delete(pos);
+    cpl_test_error(CPL_ERROR_NONE);
+    {
+        hdrl_parameter * rect = hdrl_overscan_parameter_get_rect_region(hpar);
+        cpl_test_eq(hdrl_rect_region_get_llx(rect), 1);
+        cpl_test_eq(hdrl_rect_region_get_lly(rect), 1);
+        cpl_test_eq(hdrl_rect_region_get_urx(rect), 20);
+        cpl_test_eq(hdrl_rect_region_get_ury(rect), 20);
+    }
+    cpl_test_eq(hdrl_overscan_parameter_get_box_hsize(hpar), 10);
+    cpl_test_eq(hdrl_overscan_parameter_get_ccd_ron(hpar), 10.);
+    cpl_test_eq(hdrl_overscan_parameter_get_correction_direction(hpar),
+                HDRL_X_AXIS);
+    {
+        hdrl_parameter * col = hdrl_overscan_parameter_get_collapse(hpar);
+        cpl_test(hdrl_collapse_parameter_is_minmax(col));
+        cpl_test(!hdrl_collapse_parameter_is_mean(col));
+        cpl_test_eq(hdrl_collapse_minmax_parameter_get_nlow(col), 2);
+        cpl_test_eq(hdrl_collapse_minmax_parameter_get_nhigh(col), 3);
+    }
+
+    hdrl_parameter_destroy(hpar);
+}
+
 /*----------------------------------------------------------------------------*/
 /**
- @brief Check hdrl_overscan_compute proper error on null input images
- @return cpl_error_code
+  @brief Check hdrl_overscan_compute proper error on null input images
+  @return cpl_error_code
  */
 /*----------------------------------------------------------------------------*/
 static cpl_error_code hdrl_overscan_test_null_input(void)
 {
-    hdrl_parameter                  *   os_region = NULL;
-    hdrl_parameter                  *   os_collapse = NULL;
-    hdrl_parameter                  *   os_param = NULL;
-    hdrl_overscan_compute_result    *   overscan_computation = NULL;
+    hdrl_parameter                  *   os_region;
+    hdrl_parameter                  *   os_collapse;
+    hdrl_parameter                  *   os_param;
+    hdrl_overscan_compute_result    *   overscan_computation;
 
     /* Overscan Parameters */
     os_region = hdrl_rect_region_parameter_create(1, 1, 1, 1) ;
     os_collapse = hdrl_collapse_mean_parameter_create() ;
     os_param = hdrl_overscan_parameter_create(HDRL_Y_AXIS, 1., 1, 
             os_collapse, os_region) ;
+    cpl_test(hdrl_overscan_parameter_check(os_param));
 
     /* test functionality */
     overscan_computation = hdrl_overscan_compute(NULL, os_param) ;
@@ -93,17 +136,17 @@ static cpl_error_code hdrl_overscan_test_null_input(void)
 
 /*----------------------------------------------------------------------------*/
 /**
- @brief Check hdrl_overscan_compute proper error on null input region
- @return cpl_error_code
+  @brief Check hdrl_overscan_compute proper error on null input region
+  @return cpl_error_code
  */
 /*----------------------------------------------------------------------------*/
 static cpl_error_code hdrl_overscan_test_null_region(void)
 {
-    cpl_image                       *   image_data = NULL;
+    cpl_image                       *   image_data;
     hdrl_parameter                  *   os_region = NULL;
-    hdrl_parameter                  *   os_collapse = NULL;
-    hdrl_parameter                  *   os_param = NULL;
-    hdrl_overscan_compute_result    *   overscan_computation = NULL;
+    hdrl_parameter                  *   os_collapse;
+    hdrl_parameter                  *   os_param;
+    hdrl_overscan_compute_result    *   overscan_computation;
 
     /* create input structures (on purpose not the input region) */
     image_data = cpl_image_new(1, 1, CPL_TYPE_DOUBLE);
@@ -133,11 +176,11 @@ static cpl_error_code hdrl_overscan_test_null_region(void)
 /*----------------------------------------------------------------------------*/
 static cpl_error_code hdrl_overscan_test_null_sigclip(void)
 {
-    cpl_image                       *   image_data = NULL;
-    hdrl_parameter                  *   os_region = NULL;
+    cpl_image                       *   image_data;
+    hdrl_parameter                  *   os_region;
     hdrl_parameter                  *   os_collapse = NULL;
-    hdrl_parameter                  *   os_param = NULL;
-    hdrl_overscan_compute_result    *   overscan_computation = NULL;
+    hdrl_parameter                  *   os_param;
+    hdrl_overscan_compute_result    *   overscan_computation;
 
     /* create input structures (on purpose not the input region) */
     image_data = cpl_image_new(1, 1, CPL_TYPE_DOUBLE);
@@ -161,14 +204,14 @@ static cpl_error_code hdrl_overscan_test_null_sigclip(void)
 
 /*----------------------------------------------------------------------------*/
 /**
- @brief Check hdrl_overscan_compute proper error on null input compute control
- @return cpl_error_code
+  @brief Check hdrl_overscan_compute proper error on null input compute control
+  @return cpl_error_code
  */
 /*----------------------------------------------------------------------------*/
 static cpl_error_code hdrl_overscan_test_null_params(void)
 {
     cpl_image* image_data = cpl_image_new(1, 1, CPL_TYPE_DOUBLE);
-    hdrl_overscan_compute_result * overscan_computation = NULL;
+    hdrl_overscan_compute_result * overscan_computation;
 
     /* test functionality */
     overscan_computation = hdrl_overscan_compute(image_data, NULL);
@@ -182,17 +225,17 @@ static cpl_error_code hdrl_overscan_test_null_params(void)
 
 /*----------------------------------------------------------------------------*/
 /**
- @brief Check hdrl_overscan_compute proper error on wrong input region
- @return cpl_error_code
+  @brief Check hdrl_overscan_compute proper error on wrong input region
+  @return cpl_error_code
  */
 /*----------------------------------------------------------------------------*/
 static cpl_error_code hdrl_overscan_test_wrong_region(void)
 {
-    hdrl_parameter                  *   os_region = NULL;
-    hdrl_parameter                  *   os_collapse = NULL;
-    hdrl_parameter                  *   os_param = NULL;
-    cpl_image                       *   image_data = NULL;
-    hdrl_overscan_compute_result    *   computation = NULL;
+    hdrl_parameter                  *   os_region;
+    hdrl_parameter                  *   os_collapse;
+    hdrl_parameter                  *   os_param;
+    cpl_image                       *   image_data;
+    hdrl_overscan_compute_result    *   computation;
 
     /* create input image  */
     image_data = cpl_image_new(5, 10, CPL_TYPE_DOUBLE);
@@ -230,21 +273,21 @@ static cpl_error_code hdrl_overscan_test_wrong_region(void)
 
 /*----------------------------------------------------------------------------*/
 /**
- @brief Check hdrl_overscan_compute proper error on wrong input region
- @return cpl_error_code
+  @brief Check hdrl_overscan_compute proper error on wrong input region
+  @return cpl_error_code
  */
 /*----------------------------------------------------------------------------*/
 static double hdrl_overscan_test_uniform_image(const double inp_value)
 {
     double                              out_value = 0;
-    cpl_image                       *   image_data = NULL;
-    cpl_image                       *   image_errs = NULL;
+    cpl_image                       *   image_data;
+    cpl_image                       *   image_errs;
     hdrl_image                      *   image;
-    hdrl_overscan_compute_result    *   comp_res = NULL;
-    hdrl_overscan_correct_result    *   overscan_correction = NULL;
-    hdrl_parameter                  *   os_region = NULL;
-    hdrl_parameter                  *   os_collapse = NULL;
-    hdrl_parameter                  *   os_param = NULL;
+    hdrl_overscan_compute_result    *   comp_res;
+    hdrl_overscan_correct_result    *   overscan_correction;
+    hdrl_parameter                  *   os_region;
+    hdrl_parameter                  *   os_collapse;
+    hdrl_parameter                  *   os_param;
 
     /* Create input structures (on purpose not the input region) */
     image_data = cpl_image_new(100, 100, HDRL_TYPE_DATA);
@@ -252,7 +295,7 @@ static double hdrl_overscan_test_uniform_image(const double inp_value)
     image_errs = cpl_image_new(100, 100, HDRL_TYPE_ERROR);
     cpl_image_add_scalar(image_errs, inp_value);
     cpl_image_power(image_errs, 0.5);
-    image = hdrl_image_wrap(image_data, image_errs, NULL);
+    image = hdrl_image_wrap(image_data, image_errs, NULL, CPL_FALSE);
 
     /* Overscan Parameters */
     os_region = hdrl_rect_region_parameter_create(1, 1, 100, 100) ;
@@ -272,7 +315,7 @@ static double hdrl_overscan_test_uniform_image(const double inp_value)
                            hdrl_image_get_image(comp_res->correction));
     cpl_test_abs(out_value, inp_value, HDRL_EPS_DATA);
 
-    overscan_correction = hdrl_overscan_correct(image, NULL, 1, comp_res);
+    overscan_correction = hdrl_overscan_correct(image, NULL, comp_res);
     cpl_test_nonnull(overscan_correction);
 
     hdrl_overscan_compute_result_delete(comp_res);
@@ -283,8 +326,8 @@ static double hdrl_overscan_test_uniform_image(const double inp_value)
 
 /*----------------------------------------------------------------------------*/
 /**
- @brief Check overscan directions and shrinking window
- @return cpl_error_code
+  @brief Check overscan directions and shrinking window
+  @return cpl_error_code
  */
 /*----------------------------------------------------------------------------*/
 static cpl_error_code hdrl_overscan_test_dir(cpl_size Nx, cpl_size Ny, int hbox)
@@ -354,8 +397,10 @@ static cpl_error_code hdrl_overscan_test_dir(cpl_size Nx, cpl_size Ny, int hbox)
     }
 
     /* test compute x direction */
-    hdrl_overscan_parameter_update(os_param, HDRL_X_AXIS,
-            error * sqrt(Nx * (1 + 2 * hbox)), hbox) ;
+
+    hdrl_parameter_delete(os_param) ;
+    os_param = hdrl_overscan_parameter_create(HDRL_X_AXIS,
+            error * sqrt(Nx * (1 + 2 * hbox)), hbox, os_collapse, os_region) ;
     res_os_comp_turn = hdrl_overscan_compute(image_data, os_param);
 
     hdrl_parameter_delete(os_region) ;
@@ -397,7 +442,7 @@ static cpl_error_code hdrl_overscan_test_dir(cpl_size Nx, cpl_size Ny, int hbox)
 
 
     /* test correct y direction */
-    res_os_cor = hdrl_overscan_correct(image, NULL, 2, res_os_comp);
+    res_os_cor = hdrl_overscan_correct(image, NULL, res_os_comp);
     cpl_test_error(CPL_ERROR_NONE);
 
     {
@@ -429,18 +474,17 @@ static cpl_error_code hdrl_overscan_test_dir(cpl_size Nx, cpl_size Ny, int hbox)
         cpl_image_delete(ex);
     }
 
-    res_os_cor_turn = hdrl_overscan_correct(image, NULL, 4, res_os_comp_turn);
+    res_os_cor_turn = hdrl_overscan_correct(image, NULL, res_os_comp_turn);
     cpl_test_error(CPL_ERROR_NONE);
 
     {
         /* overscan in x direction constant over whole axis */
         cpl_image * ex = cpl_image_duplicate(image_data);
         cpl_image_subtract_scalar(ex,
-                                  hdrl_image_get_pixel(res_os_comp_turn->correction,
-                                                       1, 1, NULL, &rej));
-        cpl_test_image_abs(ex,
-                           hdrl_image_get_image(res_os_cor_turn->corrected),
-                           2 * (1 + 2 * hbox) * Nx * HDRL_EPS_DATA);
+                hdrl_image_get_pixel(res_os_comp_turn->correction, 1, 1,
+                                     &rej).data);
+        cpl_test_image_abs(ex, hdrl_image_get_image(res_os_cor_turn->corrected),
+                2 * (1 + 2 * hbox) * Nx * HDRL_EPS_DATA);
 
         /* gaussian error */
         for (cpl_size x = 0; x < Nx; x++) {
@@ -476,8 +520,8 @@ static cpl_error_code hdrl_overscan_test_dir(cpl_size Nx, cpl_size Ny, int hbox)
 
 /*----------------------------------------------------------------------------*/
 /**
- @brief Check single pixel overscan
- @return cpl_error_code
+  @brief Check single pixel overscan
+  @return cpl_error_code
  */
 /*----------------------------------------------------------------------------*/
 static cpl_error_code hdrl_overscan_test_full_hbox(
@@ -491,7 +535,7 @@ static cpl_error_code hdrl_overscan_test_full_hbox(
     hdrl_parameter                  *   os_region = NULL;
     hdrl_parameter                  *   os_collapse = NULL;
     hdrl_parameter                  *   os_param = NULL;
-    hdrl_overscan_compute_result    *   res_os_comp = NULL;
+    hdrl_overscan_compute_result    *   res_os_comp;
     hdrl_overscan_correct_result    *   res_os_cor = NULL;
 
     /* sets overscan to use full region and emit single pixel value */
@@ -508,43 +552,48 @@ static cpl_error_code hdrl_overscan_test_full_hbox(
     cpl_image_power(image_errs, 0.5);
 
     /* Overscan Parameters */
-    os_region = hdrl_rect_region_parameter_create(1, 1, Nx, Ny) ;
-    os_collapse = hdrl_collapse_mean_parameter_create() ;
+    os_region   = hdrl_rect_region_parameter_create(1, 1, Nx, Ny);
+    os_collapse = hdrl_collapse_mean_parameter_create();
+
     /* invalid boxsize */
     os_param = hdrl_overscan_parameter_create(HDRL_Y_AXIS,
-            error * sqrt(Nx * Ny), -2, os_collapse, os_region) ;
+            error * sqrt(Nx * Ny), -2, os_collapse, os_region);
 
-    res_os_comp = hdrl_overscan_compute(image_data, os_param);
+    hdrl_overscan_compute(image_data, os_param);
     cpl_test_error(CPL_ERROR_ILLEGAL_INPUT);
 
     /* test compute y direction */
-    hdrl_overscan_parameter_update(os_param, HDRL_Y_AXIS,
-            error * sqrt(Nx * Ny), HDRL_OVERSCAN_FULL_BOX) ;
-
+    hdrl_parameter_delete(os_param);
+    os_param = hdrl_overscan_parameter_create(HDRL_Y_AXIS,
+											  error * sqrt(Nx * Ny),
+											  HDRL_OVERSCAN_FULL_BOX,
+											  os_collapse, os_region);
     res_os_comp = hdrl_overscan_compute(image_data, os_param);
 
-    hdrl_parameter_delete(os_region) ;
-    hdrl_parameter_delete(os_collapse) ;
-    hdrl_parameter_delete(os_param) ;
+    hdrl_parameter_delete(os_region);
+    hdrl_parameter_delete(os_collapse);
+    hdrl_parameter_delete(os_param);
 
     cpl_test_error(CPL_ERROR_NONE);
 
     {
         /* we expect a row with all the same overscan value */
         hdrl_image * ex = hdrl_image_new(Nx, 1);
-        hdrl_image_add_scalar(ex, (Nx - 1.) / 2., error);
+
+        hdrl_image_add_scalar(ex, (hdrl_value){(Nx - 1.) / 2., error});
+
         /* cpl mean implementation has a rather large error */
         hdrl_test_image_abs(ex, res_os_comp->correction,
-                            2 * Nx * Ny * HDRL_EPS_DATA);
-
+        						2 * Nx * Ny * HDRL_EPS_DATA);
         hdrl_test_image_abs(ex, res_os_comp->correction,
-                           Nx * Ny * HDRL_EPS_DATA);
+        						Nx * Ny * HDRL_EPS_DATA);
 
         hdrl_image_delete(ex);
     }
 
     hdrl_overscan_compute_result_delete(res_os_comp);
     hdrl_overscan_correct_result_delete(res_os_cor);
+
     hdrl_image_delete(image);
 
     return cpl_error_get_code();
@@ -552,8 +601,8 @@ static cpl_error_code hdrl_overscan_test_full_hbox(
 
 /*----------------------------------------------------------------------------*/
 /**
- @brief Check result of turned image when changing direction
- @return cpl_error_code
+  @brief Check result of turned image when changing direction
+  @return cpl_error_code
  */
 /*----------------------------------------------------------------------------*/
 static cpl_error_code hdrl_overscan_test_turn_eq(
@@ -562,18 +611,52 @@ static cpl_error_code hdrl_overscan_test_turn_eq(
         int                         hbox,
         hdrl_oscan_collapse_test    method)
 {
-    const double                        error = 10;
-    hdrl_image * image = hdrl_image_new(Nx, Ny);
-    hdrl_image * image_t;
+	cpl_ensure_code(method == HDRL_OSCAN_COLLAPSE_TEST_MEAN          ||
+					method == HDRL_OSCAN_COLLAPSE_TEST_MEDIAN        ||
+					method == HDRL_OSCAN_COLLAPSE_TEST_WEIGHTED_MEAN ||
+					method == HDRL_OSCAN_COLLAPSE_TEST_SIGCLIP       ||
+					method == HDRL_OSCAN_COLLAPSE_TEST_MINMAX,
+				    CPL_ERROR_ILLEGAL_INPUT);
+
+    hdrl_parameter *os_collapse = NULL;
+    if (method == HDRL_OSCAN_COLLAPSE_TEST_MEAN) {
+        cpl_msg_info(cpl_func, "Mean method hbox %d, Nx %ld, Ny %ld",
+                     hbox, (long)Nx, (long)Ny);
+        os_collapse = hdrl_collapse_mean_parameter_create();
+    } else if (method == HDRL_OSCAN_COLLAPSE_TEST_MEDIAN) {
+        cpl_msg_info(cpl_func, "Median method hbox %d, Nx %ld, Ny %ld",
+                     hbox, (long)Nx, (long)Ny);
+        os_collapse = hdrl_collapse_median_parameter_create();
+    } else if (method == HDRL_OSCAN_COLLAPSE_TEST_WEIGHTED_MEAN) {
+        cpl_msg_info(cpl_func, "Weighted Median method hbox %d, Nx %ld, Ny %ld",
+                     hbox, (long)Nx, (long)Ny);
+        os_collapse = hdrl_collapse_weighted_mean_parameter_create();
+    } else if (method == HDRL_OSCAN_COLLAPSE_TEST_SIGCLIP) {
+        cpl_msg_info(cpl_func, "Sigma-Clipping method hbox %d, Nx %ld, Ny %ld",
+                     hbox, (long)Nx, (long)Ny);
+        os_collapse = hdrl_collapse_sigclip_parameter_create(3., 3., 3) ;
+    } else if (method == HDRL_OSCAN_COLLAPSE_TEST_MINMAX) {
+        cpl_msg_info(cpl_func, "MinMax method hbox %d, Nx %ld, Ny %ld",
+                     hbox, (long)Nx, (long)Ny);
+        os_collapse = hdrl_collapse_minmax_parameter_create(3, 3);
+    }
+
+
+    const double error = 10;
+
+    hdrl_image *image = hdrl_image_new(Nx, Ny);
+    hdrl_image *image_t;
+
     cpl_image * image_data = hdrl_image_get_image(image);
     cpl_image * image_errs = hdrl_image_get_error(image);
-    hdrl_parameter                  *   os_region = NULL;
-    hdrl_parameter                  *   os_collapse = NULL;
-    hdrl_parameter                  *   os_param = NULL;
-    hdrl_overscan_compute_result    *   res_os_comp = NULL;
-    hdrl_overscan_compute_result    *   res_os_comp_turn = NULL;
-    hdrl_overscan_correct_result    *   res_os_cor = NULL;
-    hdrl_overscan_correct_result    *   res_os_cor_turn = NULL;
+
+    hdrl_parameter *os_region = NULL;
+    hdrl_parameter *os_param  = NULL;
+
+    hdrl_overscan_compute_result *res_os_comp      = NULL;
+    hdrl_overscan_compute_result *res_os_comp_turn = NULL;
+    hdrl_overscan_correct_result *res_os_cor       = NULL;
+    hdrl_overscan_correct_result *res_os_cor_turn  = NULL;
 
     for (cpl_size x = 0; x < Nx; x++) {
         for (cpl_size y = 0; y < Ny; y++) {
@@ -587,20 +670,7 @@ static cpl_error_code hdrl_overscan_test_turn_eq(
     image_t = hdrl_image_duplicate(image);
     hdrl_image_turn(image_t, +1);
     
-    if (method == HDRL_OSCAN_COLLAPSE_TEST_MEAN) {
-        cpl_msg_info(cpl_func, "Mean method hbox %d, Nx %ld, Ny %ld",
-                     hbox, (long)Nx, (long)Ny);
-        os_collapse = hdrl_collapse_mean_parameter_create() ;
-    } else if (method == HDRL_OSCAN_COLLAPSE_TEST_MEDIAN) {
-        cpl_msg_info(cpl_func, "Median method hbox %d, Nx %ld, Ny %ld",
-                     hbox, (long)Nx, (long)Ny);
-        os_collapse = hdrl_collapse_median_parameter_create() ;
 
-    } else if (method == HDRL_OSCAN_COLLAPSE_TEST_SIGCLIP) {
-        cpl_msg_info(cpl_func, "Sigma-Clipping method hbox %d, Nx %ld, Ny %ld",
-                     hbox, (long)Nx, (long)Ny);
-        os_collapse = hdrl_collapse_sigclip_parameter_create(3.,3.,3) ;
-    }
 
     /* Overscan Parameters */
     os_region = hdrl_rect_region_parameter_create(1, 1, Nx, Ny) ;
@@ -613,9 +683,9 @@ static cpl_error_code hdrl_overscan_test_turn_eq(
 
     /* test compute x direction */
     hdrl_rect_region_parameter_update(os_region, 1, 1, Ny, Nx) ;
-    hdrl_overscan_parameter_update(os_param, HDRL_X_AXIS,
-            error * sqrt(Ny * (1 + 2 * hbox)), hbox) ;
-
+    hdrl_parameter_delete(os_param) ;
+    os_param = hdrl_overscan_parameter_create(HDRL_X_AXIS,
+            error * sqrt(Ny * (1 + 2 * hbox)), hbox, os_collapse, os_region) ;
     res_os_comp_turn = hdrl_overscan_compute(hdrl_image_get_image(image_t),
                                              os_param);
     cpl_test_error(CPL_ERROR_NONE);
@@ -642,17 +712,35 @@ static cpl_error_code hdrl_overscan_test_turn_eq(
     }
 
     /* test correct y direction */
-    res_os_cor = hdrl_overscan_correct(image, NULL, 8, res_os_comp);
+    res_os_cor = hdrl_overscan_correct(image, NULL, res_os_comp);
     cpl_test_error(CPL_ERROR_NONE);
 
-    res_os_cor_turn = hdrl_overscan_correct(image_t, NULL, 16,
-                                            res_os_comp_turn);
+    res_os_cor_turn = hdrl_overscan_correct(image_t, NULL, res_os_comp_turn);
     cpl_test_error(CPL_ERROR_NONE);
 
     hdrl_image_turn(res_os_cor_turn->corrected, -1);
     hdrl_test_image_abs(res_os_cor->corrected, res_os_cor_turn->corrected,
                        (1 + hbox) * Ny * HDRL_EPS_DATA);
 
+	/* Get corrected */
+	hdrl_image *imgCorrected1 = hdrl_overscan_correct_result_get_corrected(res_os_cor);
+	cpl_test_error(CPL_ERROR_NONE);
+	cpl_test_nonnull(imgCorrected1);
+	hdrl_image *imgCorrected2 = hdrl_overscan_correct_result_unset_corrected(res_os_cor);
+	cpl_test_error(CPL_ERROR_NONE);
+	cpl_test_nonnull(imgCorrected2);
+	hdrl_image_delete(imgCorrected2);
+
+	/* Get badmask */
+	cpl_image *cpImgBadMask_1 = hdrl_overscan_correct_result_get_badmask(res_os_cor);
+	cpl_test_error(CPL_ERROR_NONE);
+	cpl_test_nonnull(cpImgBadMask_1);
+	cpl_image *cpImgBadMask_2 = hdrl_overscan_correct_result_unset_badmask(res_os_cor);
+	cpl_test_error(CPL_ERROR_NONE);
+	cpl_test_nonnull(cpImgBadMask_2);
+	cpl_image_delete(cpImgBadMask_2);
+
+
     hdrl_overscan_compute_result_delete(res_os_comp);
     hdrl_overscan_compute_result_delete(res_os_comp_turn);
     hdrl_overscan_correct_result_delete(res_os_cor);
@@ -665,74 +753,158 @@ static cpl_error_code hdrl_overscan_test_turn_eq(
 
 /*----------------------------------------------------------------------------*/
 /**
- @brief Check case where a overscan box only contains bad pixels
- @return cpl_error_code
+  @brief Check case where a overscan box only contains bad pixels
+  @return cpl_error_code
  */
 /*----------------------------------------------------------------------------*/
 static cpl_error_code hdrl_overscan_test_empty_box(
         hdrl_oscan_collapse_test    method)
 {
-    cpl_size                            Nx = 10 ;
-    cpl_size                            Ny = 10;
-    cpl_image * image_data = cpl_image_new(Nx, Ny, HDRL_TYPE_DATA);
-    cpl_image * image_errs = cpl_image_new(Nx, Ny, HDRL_TYPE_ERROR);
-    hdrl_parameter                  *   os_region = NULL;
-    hdrl_parameter                  *   os_collapse = NULL;
-    hdrl_parameter                  *   os_param = NULL;
-    hdrl_overscan_compute_result    *   res_os_comp = NULL;
 
+	cpl_ensure_code(method == HDRL_OSCAN_COLLAPSE_TEST_MEAN          ||
+					method == HDRL_OSCAN_COLLAPSE_TEST_MEDIAN        ||
+					method == HDRL_OSCAN_COLLAPSE_TEST_WEIGHTED_MEAN ||
+					method == HDRL_OSCAN_COLLAPSE_TEST_SIGCLIP       ||
+					method == HDRL_OSCAN_COLLAPSE_TEST_MINMAX,
+					CPL_ERROR_ILLEGAL_INPUT);
 
     /* Overscan Parameters */
-    if (method == HDRL_OSCAN_COLLAPSE_TEST_MEAN) {
+    hdrl_parameter *os_collapse = NULL;
+    if(method == HDRL_OSCAN_COLLAPSE_TEST_MEAN) {
         cpl_msg_info(cpl_func, "check empty box MEAN");
-        os_collapse = hdrl_collapse_mean_parameter_create() ;
+        os_collapse = hdrl_collapse_mean_parameter_create();
     } else if (method == HDRL_OSCAN_COLLAPSE_TEST_MEDIAN) {
         cpl_msg_info(cpl_func, "check empty box MEDIAN");
-        os_collapse = hdrl_collapse_median_parameter_create() ;
+        os_collapse = hdrl_collapse_median_parameter_create();
+    } else if (method == HDRL_OSCAN_COLLAPSE_TEST_WEIGHTED_MEAN) {
+        cpl_msg_info(cpl_func, "check empty box WEIGHTED_MEAN");
+        os_collapse = hdrl_collapse_weighted_mean_parameter_create();
     } else if (method == HDRL_OSCAN_COLLAPSE_TEST_SIGCLIP) {
         cpl_msg_info(cpl_func, "check empty box SIGCLIP");
-        os_collapse = hdrl_collapse_sigclip_parameter_create(3.,3.,3) ;
+        os_collapse = hdrl_collapse_sigclip_parameter_create(3., 3., 3);
+    } else if (method == HDRL_OSCAN_COLLAPSE_TEST_MINMAX) {
+        cpl_msg_info(cpl_func, "check empty box MINMAX");
+        os_collapse = hdrl_collapse_minmax_parameter_create(3, 3);
     }
-    os_region = hdrl_rect_region_parameter_create(1, 1, Nx, Ny) ;
-    os_param = hdrl_overscan_parameter_create(HDRL_Y_AXIS, 1., 0, 
-            os_collapse, os_region) ;
+
+    cpl_size Nx = 10;
+    cpl_size Ny = 10;
+    cpl_image *image_data = cpl_image_new(Nx, Ny, HDRL_TYPE_DATA);
+
+    hdrl_parameter *os_region = hdrl_rect_region_parameter_create(1, 1, Nx, Ny);
+    hdrl_parameter *os_param  = hdrl_overscan_parameter_create(
+    								HDRL_Y_AXIS, 1., 0, os_collapse, os_region);
 
     /* reject one row (= one box */
     for (cpl_size i = 0; i < Ny; i++) cpl_image_reject(image_data, 2, i + 1);
 
     /* test compute y direction */
+    hdrl_overscan_compute_result *res_os_comp;
     res_os_comp = hdrl_overscan_compute(image_data, os_param);
-    
-    hdrl_parameter_delete(os_region) ;
-    hdrl_parameter_delete(os_collapse) ;
-    hdrl_parameter_delete(os_param) ;
-    
     cpl_test_error(CPL_ERROR_NONE);
 
-    /* expecting bad pixels in the bad box */
-    {
-        int rej;
-        cpl_test_eq(cpl_image_get(res_os_comp->contribution, 2, 1, &rej), 0);
-        cpl_test(hdrl_image_is_rejected(res_os_comp->correction, 2, 1));
-        cpl_test(cpl_image_is_rejected(res_os_comp->red_chi2, 2, 1));
-        if (res_os_comp->sigclip_reject_low) {
-            cpl_test(cpl_image_is_rejected(res_os_comp->sigclip_reject_low,
-                                           2, 1));
-            cpl_test(cpl_image_is_rejected(res_os_comp->sigclip_reject_high,
-                                           2, 1));
-        }
+
+    hdrl_parameter_delete(os_region);
+    hdrl_parameter_delete(os_collapse);
+    hdrl_parameter_delete(os_param);
+    
+
+	int rej;
+	cpl_test_eq(cpl_image_get(res_os_comp->contribution, 2, 1, &rej), 0);
+	cpl_test(hdrl_image_is_rejected(res_os_comp->correction, 2, 1));
+	cpl_test(cpl_image_is_rejected(res_os_comp->red_chi2, 2, 1));
+
+	/* Get correction */
+	hdrl_image *img1 = hdrl_overscan_compute_result_get_correction(res_os_comp);
+	cpl_test_error(CPL_ERROR_NONE);
+	cpl_test_nonnull(img1);
+	hdrl_image *img2 = hdrl_overscan_compute_result_unset_correction(res_os_comp);
+	cpl_test_error(CPL_ERROR_NONE);
+	cpl_test_nonnull(img2);
+	hdrl_image_delete(img2);
+
+	/* Get contribution */
+	cpl_image *cpImg1 = hdrl_overscan_compute_result_get_contribution(res_os_comp);
+	cpl_test_error(CPL_ERROR_NONE);
+	cpl_test_nonnull(cpImg1);
+	cpl_image *cpImg2 = hdrl_overscan_compute_result_unset_contribution(res_os_comp);
+	cpl_test_error(CPL_ERROR_NONE);
+	cpl_test_nonnull(cpImg2);
+	cpl_image_delete(cpImg2);
+
+	/* Get chi2 */
+	cpl_image *cpImgCh2_1 = hdrl_overscan_compute_result_get_chi2(res_os_comp);
+	cpl_test_error(CPL_ERROR_NONE);
+	cpl_test_nonnull(cpImgCh2_1);
+	cpl_image *cpImgCh2_2 = hdrl_overscan_compute_result_unset_chi2(res_os_comp);
+	cpl_test_error(CPL_ERROR_NONE);
+	cpl_test_nonnull(cpImgCh2_2);
+	cpl_image_delete(cpImgCh2_2);
+
+	/* Get red chi2 */
+	cpl_image *cpImgRedCh2_1 = hdrl_overscan_compute_result_get_red_chi2(res_os_comp);
+	cpl_test_error(CPL_ERROR_NONE);
+	cpl_test_nonnull(cpImgRedCh2_1);
+	cpl_image *cpImgRedCh2_2 = hdrl_overscan_compute_result_unset_red_chi2(res_os_comp);
+	cpl_test_error(CPL_ERROR_NONE);
+	cpl_test_nonnull(cpImgRedCh2_2);
+	cpl_image_delete(cpImgRedCh2_2);
+
+
+    /* Overscan Parameters - SigClip and MinMax*/
+
+	if (method == HDRL_OSCAN_COLLAPSE_TEST_SIGCLIP) {
+
+    	/* Get overscan SigClip Low */
+    	cpl_image *cpImgSGLow_1 = hdrl_overscan_compute_result_get_sigclip_reject_low(res_os_comp);
+    	cpl_test_error(CPL_ERROR_NONE);
+    	cpl_test_nonnull(cpImgSGLow_1);
+    	cpl_image *cpImgSGLow_2 = hdrl_overscan_compute_result_unset_sigclip_reject_low(res_os_comp);
+    	cpl_test_error(CPL_ERROR_NONE);
+    	cpl_test_nonnull(cpImgSGLow_2);
+    	cpl_image_delete(cpImgSGLow_2);
+
+    	/* Get overscan SigClip High */
+    	cpl_image *cpImgSGHigh_1 = hdrl_overscan_compute_result_get_sigclip_reject_high(res_os_comp);
+    	cpl_test_error(CPL_ERROR_NONE);
+    	cpl_test_nonnull(cpImgSGHigh_1);
+    	cpl_image *cpImgSGHigh_2 = hdrl_overscan_compute_result_unset_sigclip_reject_high(res_os_comp);
+    	cpl_test_error(CPL_ERROR_NONE);
+    	cpl_test_nonnull(cpImgSGHigh_2);
+    	cpl_image_delete(cpImgSGHigh_2);
+
+    } else if (method == HDRL_OSCAN_COLLAPSE_TEST_MINMAX) {
+
+    	/* Get overscan MinMax Low */
+    	cpl_image *cpImgMMLow_1 = hdrl_overscan_compute_result_get_minmax_reject_low(res_os_comp);
+    	cpl_test_error(CPL_ERROR_NONE);
+    	cpl_test_nonnull(cpImgMMLow_1);
+    	cpl_image *cpImgMMLow_2 = hdrl_overscan_compute_result_unset_minmax_reject_low(res_os_comp);
+    	cpl_test_error(CPL_ERROR_NONE);
+    	cpl_test_nonnull(cpImgMMLow_2);
+    	cpl_image_delete(cpImgMMLow_2);
+
+    	/* Get overscan MinMax High */
+    	cpl_image *cpImgMMHigh_1 = hdrl_overscan_compute_result_get_minmax_reject_high(res_os_comp);
+    	cpl_test_error(CPL_ERROR_NONE);
+    	cpl_test_nonnull(cpImgMMHigh_1);
+    	cpl_image *cpImgMMHigh_2 = hdrl_overscan_compute_result_unset_minmax_reject_high(res_os_comp);
+    	cpl_test_error(CPL_ERROR_NONE);
+    	cpl_test_nonnull(cpImgMMHigh_2);
+    	cpl_image_delete(cpImgMMHigh_2);
     }
 
     hdrl_overscan_compute_result_delete(res_os_comp);
+
     cpl_image_delete(image_data);
-    cpl_image_delete(image_errs);
+
 
     return cpl_error_get_code();
 }
 
 /*----------------------------------------------------------------------------*/
 /**
- @brief   Unit tests of overscan functions module
+  @brief   Unit tests of overscan functions module
  */
 /*----------------------------------------------------------------------------*/
 int main(void)
@@ -741,6 +913,9 @@ int main(void)
     cpl_error_code code;
     double inp_value = 0;
 
+    /* parameter parsing tests */
+    test_parlist();
+
     /* Overscan with NULL input images */
     code = hdrl_overscan_test_null_input();
     cpl_test_eq_error(code, CPL_ERROR_NULL_INPUT);
@@ -767,6 +942,9 @@ int main(void)
     cpl_size anx[] = {97,  45, 200};
     cpl_size any[] = {575, 34, 200};
 
+    hdrl_overscan_test_turn_eq(0, 0, 0, -1);
+    cpl_test_error(CPL_ERROR_ILLEGAL_INPUT);
+
     for (size_t i = 0; i < sizeof(anx) / sizeof(anx[0]); i++) {
         cpl_size nx = anx[i];
         cpl_size ny = any[i];
@@ -776,20 +954,41 @@ int main(void)
         }
 
         for (int hbox = 0; hbox < 6; hbox+=2) {
+
             hdrl_overscan_test_turn_eq(nx, ny, hbox,
-                    HDRL_OSCAN_COLLAPSE_TEST_MEAN);
+            					       HDRL_OSCAN_COLLAPSE_TEST_MEAN);
+            cpl_test_error(CPL_ERROR_NONE);
             hdrl_overscan_test_turn_eq(nx, ny, hbox,
-                    HDRL_OSCAN_COLLAPSE_TEST_MEDIAN);
+            		                   HDRL_OSCAN_COLLAPSE_TEST_MEDIAN);
+            cpl_test_error(CPL_ERROR_NONE);
             hdrl_overscan_test_turn_eq(nx, ny, hbox,
-                    HDRL_OSCAN_COLLAPSE_TEST_SIGCLIP);
+            							HDRL_OSCAN_COLLAPSE_TEST_WEIGHTED_MEAN);
+            cpl_test_error(CPL_ERROR_NONE);
+            hdrl_overscan_test_turn_eq(nx, ny, hbox,
+            		                   HDRL_OSCAN_COLLAPSE_TEST_SIGCLIP);
+            cpl_test_error(CPL_ERROR_NONE);
+            hdrl_overscan_test_turn_eq(nx, ny, hbox,
+            		                   HDRL_OSCAN_COLLAPSE_TEST_MINMAX);
+            cpl_test_error(CPL_ERROR_NONE);
         }
 
         hdrl_overscan_test_full_hbox(nx, ny);
     }
 
+    hdrl_overscan_test_empty_box(-1);
+    cpl_test_error(CPL_ERROR_ILLEGAL_INPUT);
     hdrl_overscan_test_empty_box(HDRL_OSCAN_COLLAPSE_TEST_MEAN);
+    cpl_test_error(CPL_ERROR_NONE);
     hdrl_overscan_test_empty_box(HDRL_OSCAN_COLLAPSE_TEST_MEDIAN);
+    cpl_test_error(CPL_ERROR_NONE);
+    hdrl_overscan_test_empty_box(HDRL_OSCAN_COLLAPSE_TEST_WEIGHTED_MEAN);
+    cpl_test_error(CPL_ERROR_NONE);
     hdrl_overscan_test_empty_box(HDRL_OSCAN_COLLAPSE_TEST_SIGCLIP);
+    cpl_test_error(CPL_ERROR_NONE);
+    hdrl_overscan_test_empty_box(HDRL_OSCAN_COLLAPSE_TEST_MINMAX);
+    cpl_test_error(CPL_ERROR_NONE);
+
+
 
     /** \todo Test expected results with uniform frame + spikes */
     //cpl_test(hdrl_overscan_test_uniform_image_and_outliers(),value);
@@ -797,5 +996,5 @@ int main(void)
     /** \todo Test expected results with uniform frame + noise */
     //cpl_test(hdrl_overscan_test_uniform_image_and_noise(),value);
 
-    return cpl_test_end(cpl_error_get_code());
+    return cpl_test_end(0);
 }
