@@ -47,6 +47,14 @@
 
 void hdrl_strehl_test_parlist(void)
 {
+	/* Test null parameters */
+	hdrl_parameter *pFake1 = hdrl_strehl_parameter_create(
+			0., 0., 0., 0., 0., 0., 0., 0.);
+	hdrl_strehl_parameter_verify(NULL);
+	cpl_test_error(CPL_ERROR_NULL_INPUT);
+    hdrl_parameter_delete(pFake1);
+
+
     /* parameter parsing smoketest */
     double wavelength = 1.635e-6;
     double m1 = 5.08/2;
@@ -57,10 +65,62 @@ void hdrl_strehl_test_parlist(void)
     double r2 = 1.5;
     double r3 = 2.0;
 
+
+    /* Create parameter */
     hdrl_parameter * hpar;
     hdrl_parameter * strehl_def =
         hdrl_strehl_parameter_create(wavelength, m1, m2, psx, psy, r1, r2, r3);
 
+
+    /* Check parameter */
+    cpl_test(!hdrl_strehl_parameter_check(pFake1));
+    cpl_test( hdrl_strehl_parameter_check(strehl_def));
+    cpl_test_error(CPL_ERROR_NONE);
+
+
+    /* Gets */
+
+    cpl_test_eq(hdrl_strehl_parameter_get_wavelength(NULL), -1.);
+    cpl_test_error(CPL_ERROR_NULL_INPUT);
+    cpl_test_eq(hdrl_strehl_parameter_get_wavelength(strehl_def), wavelength);
+    cpl_test_error(CPL_ERROR_NONE);
+
+    cpl_test_eq(hdrl_strehl_parameter_get_m1(NULL), -1.);
+	cpl_test_error(CPL_ERROR_NULL_INPUT);
+	cpl_test_eq(hdrl_strehl_parameter_get_m1(strehl_def), m1);
+	cpl_test_error(CPL_ERROR_NONE);
+
+	cpl_test_eq(hdrl_strehl_parameter_get_m2(NULL), -1);
+	cpl_test_error(CPL_ERROR_NULL_INPUT);
+	cpl_test_eq(hdrl_strehl_parameter_get_m2(strehl_def), m2);
+	cpl_test_error(CPL_ERROR_NONE);
+
+	cpl_test_eq(hdrl_strehl_parameter_get_pixel_scale_x(NULL), -1);
+	cpl_test_error(CPL_ERROR_NULL_INPUT);
+	cpl_test_eq(hdrl_strehl_parameter_get_pixel_scale_x(strehl_def), psx);
+	cpl_test_error(CPL_ERROR_NONE);
+
+	cpl_test_eq(hdrl_strehl_parameter_get_pixel_scale_y(NULL), -1);
+	cpl_test_error(CPL_ERROR_NULL_INPUT);
+	cpl_test_eq(hdrl_strehl_parameter_get_pixel_scale_y(strehl_def), psy);
+	cpl_test_error(CPL_ERROR_NONE);
+
+	cpl_test_eq(hdrl_strehl_parameter_get_flux_radius(NULL), -1);
+	cpl_test_error(CPL_ERROR_NULL_INPUT);
+	cpl_test_eq(hdrl_strehl_parameter_get_flux_radius(strehl_def), r1);
+	cpl_test_error(CPL_ERROR_NONE);
+
+	cpl_test_eq(hdrl_strehl_parameter_get_bkg_radius_low(NULL), -1);
+	cpl_test_error(CPL_ERROR_NULL_INPUT);
+	cpl_test_eq(hdrl_strehl_parameter_get_bkg_radius_low(strehl_def), r2);
+	cpl_test_error(CPL_ERROR_NONE);
+
+	cpl_test_eq(hdrl_strehl_parameter_get_bkg_radius_high(NULL), -1);
+	cpl_test_error(CPL_ERROR_NULL_INPUT);
+	cpl_test_eq(hdrl_strehl_parameter_get_bkg_radius_high(strehl_def), r3);
+	cpl_test_error(CPL_ERROR_NONE);
+
+
     cpl_parameterlist * strehl = hdrl_strehl_parameter_create_parlist(
                 "RECIPE", "strehl", strehl_def);
 
@@ -130,7 +190,8 @@ static hdrl_image* hdrl_strehl_test_gauss_create(void)
 /*----------------------------------------------------------------------------*/
 static cpl_error_code hdrl_strehl_test_null_input(void)
 {
-    double w = 1.635e-6;
+    double w;
+
     double m1 = 5.08/2;
     double m2 = 5.08/2*0.36;
     double psx = 0.0331932/2.;
@@ -139,20 +200,29 @@ static cpl_error_code hdrl_strehl_test_null_input(void)
     double r2 = 1.5;
     double r3 = 2.0;
 
-    hdrl_image                      * hima =NULL;
+    hdrl_parameter     *strehl_param;
+    hdrl_strehl_result  strehl_result;
 
-    hdrl_parameter                  *   strehl_param = NULL;
-    hdrl_strehl_result                  strehl_result;
-
-    /* Strehl Parameters */
+    /* test functionality - Image null*/
+    hdrl_image *hima = NULL;
+    w = 1.635e-6;
     strehl_param = hdrl_strehl_parameter_create(w, m1, m2, psx, psy, r1, r2, r3);
-
-    /* test functionality */
+    cpl_test(hdrl_strehl_parameter_check(strehl_param));
     strehl_result = hdrl_strehl_compute(hima, strehl_param) ;
-    hdrl_parameter_delete(strehl_param) ;
-
-    cpl_test(isnan(strehl_result.strehl_value.data));
     cpl_test_error(CPL_ERROR_NULL_INPUT);
+    hdrl_parameter_delete(strehl_param) ;
+    cpl_test(isnan(strehl_result.strehl_value.data));
+
+    /* Strehl Parameter wrong */
+    hima = hdrl_image_new(10, 10);
+    w = -1.;
+    strehl_param = hdrl_strehl_parameter_create(w, m1, m2, psx, psy, r1, r2, r3);
+    cpl_test(!hdrl_strehl_parameter_check(strehl_param));
+    strehl_result = hdrl_strehl_compute(hima, strehl_param);
+    cpl_test_error(CPL_ERROR_NULL_INPUT);
+    hdrl_parameter_delete(strehl_param);
+    hdrl_image_delete(hima);
+    cpl_test(isnan(strehl_result.strehl_value.data));
 
     return cpl_error_get_code();
 }
@@ -366,18 +436,15 @@ void test_strehl_with_bkg(void)
     /* realistic bkg slope */
     double slope_x = 1. / nx * 100;
 
-    cpl_image* bkg  = NULL;
-    double*    pbkg = NULL;
-
     img = compute_psf(lam, m1, m2, pscale, pscale, nx / 2., ny / 2., nx, ny);
 
     /* we multiply for a large factor to make sure that the psf has high S/N */
     cpl_image_multiply_scalar(img, 2000.);
 
     /* create a background image with a simple slope along X direction */
-    bkg = cpl_image_duplicate(img);
+    cpl_image *bkg = cpl_image_duplicate(img);
     cpl_image_multiply_scalar(bkg, 0);
-    pbkg=cpl_image_get_data_double(bkg);
+    double *pbkg=cpl_image_get_data_double(bkg);
 
 
     for(size_t j = 0; j < ny; j++) {
@@ -427,15 +494,17 @@ void test_strehl(void)
     hdrl_image_set_pixel(himg, 28, 231, (hdrl_value){1.5, 1.5});
 
     /* bad background */
-    r = compute_strehl(himg, lam, m1, m2, pscale, pscale, 1.5, -1, 4.);
-    cpl_test_error(CPL_ERROR_INCOMPATIBLE_INPUT);
-    r = compute_strehl(himg, lam, m1, m2, pscale, pscale, 1.5, 4., -1);
-    cpl_test_error(CPL_ERROR_INCOMPATIBLE_INPUT);
-    r = compute_strehl(himg, lam, m1, m2, pscale, pscale, 1.5, 5, 5);
+    compute_strehl(himg, lam, m1, m2, pscale, pscale, 1.5, -1, 4.);
     cpl_test_error(CPL_ERROR_INCOMPATIBLE_INPUT);
 
+    compute_strehl(himg, lam, m1, m2, pscale, pscale, 1.5, 4., -1);
+    cpl_test_error(CPL_ERROR_INCOMPATIBLE_INPUT);
+
+    compute_strehl(himg, lam, m1, m2, pscale, pscale, 1.5, 5, 5);
+    cpl_test_error(CPL_ERROR_INCOMPATIBLE_INPUT);
     cpl_mask_not(hdrl_image_get_mask(himg));
-    r = compute_strehl(himg, lam, m1, m2, pscale, pscale, 1.5, 5, 6);
+
+    compute_strehl(himg, lam, m1, m2, pscale, pscale, 1.5, 5, 6);
     cpl_test_error(CPL_ERROR_DATA_NOT_FOUND);
     cpl_mask_not(hdrl_image_get_mask(himg));
 
@@ -463,7 +532,7 @@ void test_strehl(void)
     cpl_test_abs(r.star_background.error, 0., rel);
 
     /* test zero background */
-    r = compute_strehl(himg, lam, m1, m2, pscale, pscale, .5, 50, 55);
+    compute_strehl(himg, lam, m1, m2, pscale, pscale, .5, 50, 55);
     cpl_test_error(CPL_ERROR_ILLEGAL_INPUT);
 
     hdrl_image_delete(himg);
@@ -483,15 +552,15 @@ void test_strehl(void)
 
     /* failing fit */
     himg = hdrl_image_new(nx, ny);
-    r = compute_strehl(himg, lam, m1, m2, pscale, pscale, .5, -1, -1);
+    compute_strehl(himg, lam, m1, m2, pscale, pscale, .5, -1, -1);
     cpl_test_error(CPL_ERROR_DATA_NOT_FOUND);
+
     hdrl_image_delete(himg);
 }
 
-
+/*
 void test_strehl_data(int argc, char * argv[])
 {
-    /* pass images via commandline to test */
     for (size_t i = 2; i < (size_t)argc; i++) {
         hdrl_image * himg;
         cpl_image * img;
@@ -501,11 +570,12 @@ void test_strehl_data(int argc, char * argv[])
         cpl_size next = cpl_frame_get_nextensions(frm);
         cpl_frame_delete(frm);
         img = cpl_image_load(argv[i], CPL_TYPE_DOUBLE, 0, 0);
-        double radius = atof(argv[1]); /* arcsec */
+        double radius = atof(argv[1]); // arcsec
         if (next == 0) {
+
             double dmad;
             cpl_image_get_mad(img, &dmad);
-            /* peak/signal to noise ratio */
+			// signal/noise
             cpl_image * err = cpl_image_duplicate(img);
             cpl_image_multiply_scalar(err, 0);
             cpl_image_add_scalar(err, (dmad * CPL_MATH_STD_MAD));
@@ -545,25 +615,10 @@ void test_strehl_data(int argc, char * argv[])
         cpl_test_abs(r.strehl_value.data, 1.0, 0);
         cpl_image_delete(img);
     }
-//    img = cpl_image_load("/tmp/jtaylor/Torino_2.fits", CPL_TYPE_DOUBLE, 0, 0);
-//    r = compute_strehl(img, 1.635e-6, 5.08/2, 5.08/2*0.36, 0.0331932, 0.0331932);
-//    cpl_test_abs(r, 1.0, 0);
-//
-//   img = cpl_image_load("/tmp/jtaylor/Teramo_4.fits", CPL_TYPE_DOUBLE, 0, 0);
-//    r = compute_strehl(img, 1.635e-6, 5.08/2, 5.08/2*0.36, 0.0165966, 0.0165966);
-//    cpl_test_abs(r, 1.0, 0);
-//
-//    img = cpl_image_load("/tmp/jtaylor/Cagliari_4.fits", CPL_TYPE_DOUBLE, 0, 0);
-//    r = compute_strehl(img, 1.635e-6, 5.08/2, 5.08/2*0.36, 0.0165966, 0.0165966);
-//    cpl_test_abs(r, 1.0, 0);
-//
-//    double d = 5.08 / 2.;
-//    img = cpl_image_load("/tmp/jtaylor/Firenze_4.fits", CPL_TYPE_DOUBLE, 0, 0);
-//    r = compute_strehl(img, 1.635e-6, d, d*0.36, 0.0165966, 0.0165966);
-//    cpl_test_abs(r, 1.0, 0);
     
 
 }
+*/
 
 /*----------------------------------------------------------------------------*/
 /**
@@ -581,7 +636,12 @@ int main(int argc, char * argv[])
     test_psf();
     test_strehl();
     test_strehl_with_bkg();
-    test_strehl_data(argc, argv);
 
+	cpl_msg_debug(cpl_func, "test_strehl_data only for command line "
+			"(argc=%d, argv=%s). If you need to test images images "
+			"via command line uncomment the function.",	argc, argv[0]);
+/*
+     test_strehl_data(argc, argv);
+*/
     return cpl_test_end(0);
 }
