@@ -34,10 +34,24 @@ namespace mosca {
 
 template<typename T>
 mosca::image image_normalise
-(mosca::image& image,
- int spa_smooth_radius, int disp_smooth_radius, 
+(const mosca::image& image,
+const mosca::image& slit_image_weight,
+int spa_smooth_radius, int disp_smooth_radius, int disp_smooth_radius_aver,
+int spa_fit_polyorder, int disp_fit_nknots, double fit_threshold,
+std::vector<T>& slit_spa_profile, std::vector<T>& slit_disp_profile);
+
+template<typename  T>
+mosca::image image_normalise_spa_local(const mosca::image& slit_image,
+ const mosca::image& slit_image_weight,
+ int spa_smooth_radius, int disp_smooth_radius, int disp_smooth_radius_aver,
  int spa_fit_polyorder, int disp_fit_nknots, double fit_threshold,
- std::vector<T>& slit_spa_profile, std::vector<T>& slit_disp_profile);
+ bool normalise_spa_local,
+ std::vector<T>& slit_spa_norm_profile, std::vector<T>& slit_disp_norm_profile);
+
+class no_flux_exception :  public std::exception
+{
+      virtual const char* what() const throw();
+};
 
 
 } /* namespace mosca */
