@@ -35,6 +35,8 @@
 #include <fors_dfs.h>
 #include <fors_utils.h>
 #include <fors_flat_normalise.h>
+#include "fors_grism.h"
+#include "fors_calibrated_slits.h"
 #include "wavelength_calibration.h"
 
 static int fors_normalise_flat_create(cpl_plugin *);
@@ -257,7 +259,7 @@ static int fors_normalise_flat_create(cpl_plugin *plugin)
     p = cpl_parameter_new_value("fors.fors_normalise_flat.sradius",
                                 CPL_TYPE_INT,
                                 "Smooth box radius for flat field along "
-                                "spatial direction (used if spa_knots < 0)",
+                                "spatial direction",
                                 "fors.fors_normalise_flat",
                                 10);
     cpl_parameter_set_alias(p, CPL_PARAMETER_MODE_CLI, "sradius");
@@ -279,19 +281,34 @@ static int fors_normalise_flat_create(cpl_plugin *plugin)
     cpl_parameterlist_append(recipe->parameters, p);
 
     /*
-     * Smooth box radius for flat field along dispersion direction
+     * Smooth box radius for flat field along dispersion direction (median)
      */
 
     p = cpl_parameter_new_value("fors.fors_normalise_flat.dradius",
                                 CPL_TYPE_INT,
-                                "Smooth box radius for flat field along "
-                                "dispersion direction (if disp_knots < 0)",
+                                "Smooth box radius (median) for flat field along "
+                                "dispersion direction",
                                 "fors.fors_normalise_flat",
                                 10);
     cpl_parameter_set_alias(p, CPL_PARAMETER_MODE_CLI, "dradius");
     cpl_parameter_disable(p, CPL_PARAMETER_MODE_ENV);
     cpl_parameterlist_append(recipe->parameters, p);
 
+    /*
+     * Smooth box radius for flat field along dispersion direction (average)
+     */
+
+    p = cpl_parameter_new_value("fors.fors_normalise_flat.dradius_aver",
+                                CPL_TYPE_INT,
+                                "Smooth box radius (average) for flat field along "
+                                "dispersion direction (performed after median "
+				"smoothing)",
+                                "fors.fors_normalise_flat",
+                                10);
+    cpl_parameter_set_alias(p, CPL_PARAMETER_MODE_CLI, "dradius_aver");
+    cpl_parameter_disable(p, CPL_PARAMETER_MODE_ENV);
+    cpl_parameterlist_append(recipe->parameters, p);
+
     /*
      * Threshold percentage for flat spline fitting with respect to the maximum
      */
@@ -356,6 +373,108 @@ static int fors_normalise_flat_destroy(cpl_plugin *plugin)
     return 0;
 }
 
+static cpl_error_code
+get_rows(const cpl_table * idscoeff_all, mosca::image& img,
+		cpl_size& first_row, cpl_size& last_row){
+
+	if (!cpl_table_has_valid(idscoeff_all, "c0"))
+		return CPL_ERROR_ILLEGAL_INPUT;
+
+	const cpl_size ny = cpl_image_get_size_y(img.get_cpl_image());
+
+	first_row = 0;
+	while (!cpl_table_is_valid(idscoeff_all, "c0", first_row))
+		first_row++;
+
+	last_row = cpl_table_get_nrow(idscoeff_all) - 1;
+	while (!cpl_table_is_valid(idscoeff_all, "c0", last_row))
+		last_row--;
+
+	return CPL_ERROR_NONE;
+}
+
+static inline cpl_table *
+generate_dummy_polytraces(const cpl_size first_row, const cpl_size last_row){
+
+	cpl_table * polytraces = cpl_table_new(2);
+	cpl_table_new_column(polytraces, "slit_id", CPL_TYPE_INT);
+	cpl_table_new_column(polytraces, "c0", CPL_TYPE_DOUBLE);
+	cpl_table_new_column(polytraces, "c1", CPL_TYPE_DOUBLE);
+	cpl_table_new_column(polytraces, "c2", CPL_TYPE_DOUBLE);
+
+	cpl_table_set_int(polytraces, "slit_id", 0, 0);
+	cpl_table_set_int(polytraces, "slit_id", 1, 0);
+	cpl_table_set_double(polytraces, "c0", 0, (double)last_row);
+	cpl_table_set_double(polytraces, "c0", 1, (double)first_row + 1.0);
+	cpl_table_set_double(polytraces, "c1", 0, 0.);
+	cpl_table_set_double(polytraces, "c1", 1, 0.);
+	cpl_table_set_double(polytraces, "c2", 0, 0.);
+	cpl_table_set_double(polytraces, "c2", 1, 0.);
+
+	return polytraces;
+}
+
+static inline
+cpl_table * generate_dummy_slits_table(const cpl_table * idscoeff, const mosca::image& img,
+		const cpl_size first_row, const cpl_size last_row){
+
+	const char *clab[6] = {"c0", "c1", "c2", "c3", "c4", "c5"};
+
+	cpl_size wdegree = 0;
+	for(cpl_size k = 0; k < 6; k++){
+		const char* cl = clab[k];
+		if(!cpl_table_has_column(idscoeff, cl)) break;
+		wdegree++;
+	}
+	wdegree--;
+	if(wdegree < 1 || wdegree > 5){
+		return NULL;
+	}
+
+	const cpl_size ny = cpl_image_get_size_y(img.get_cpl_image());
+
+	cpl_table * slits = cpl_table_new(1);
+	cpl_table_new_column(slits, "slit_id", CPL_TYPE_INT);
+	cpl_table_new_column(slits, "xtop", CPL_TYPE_DOUBLE);
+	cpl_table_new_column(slits, "ytop", CPL_TYPE_DOUBLE);
+	cpl_table_new_column(slits, "xbottom", CPL_TYPE_DOUBLE);
+	cpl_table_new_column(slits, "ybottom", CPL_TYPE_DOUBLE);
+	cpl_table_new_column(slits, "position", CPL_TYPE_INT);
+	cpl_table_new_column(slits, "length", CPL_TYPE_INT);
+	cpl_table_set_column_unit(slits, "xtop", "pixel");
+	cpl_table_set_column_unit(slits, "ytop", "pixel");
+	cpl_table_set_column_unit(slits, "xbottom", "pixel");
+	cpl_table_set_column_unit(slits, "ybottom", "pixel");
+	cpl_table_set_column_unit(slits, "position", "pixel");
+	cpl_table_set_column_unit(slits, "length", "pixel");
+	cpl_table_set_int(slits, "slit_id", 0, 0);
+
+	int cnull; //It is not checked because the first and last row should contain valid calibrations... I think
+	cpl_polynomial * top_ids = cpl_polynomial_new(1);
+	for (cpl_size k = 0; k <= wdegree; k++) {
+		double c = cpl_table_get_double(idscoeff, clab[k], 0, &cnull);
+		cpl_polynomial_set_coeff(top_ids, &k, c);
+	}
+	double xtop = cpl_polynomial_eval_1d(top_ids, 0.0, NULL) + 0.5;
+	cpl_table_set_double(slits, "xtop", 0, xtop);
+	cpl_table_set_double(slits, "ytop", 0, (double)last_row+1);
+	cpl_polynomial * botom_ids = cpl_polynomial_new(1);
+	for (cpl_size k = 0; k <= wdegree; k++) {
+		double c = cpl_table_get_double(idscoeff, clab[k], cpl_table_get_nrow(idscoeff) -1, &cnull);
+		cpl_polynomial_set_coeff(botom_ids, &k, c);
+	}
+	double xbottom = cpl_polynomial_eval_1d(botom_ids, 0.0, NULL) + 0.5;
+	cpl_table_set_double(slits, "xbottom", 0, xbottom);
+	cpl_table_set_double(slits, "ybottom", 0, (double)first_row+1);
+	cpl_table_set_int(slits, "position", 0, 0);
+	cpl_table_set_int(slits, "length", 0, (int)ny);
+
+	if(cpl_error_get_code() != CPL_ERROR_NONE)
+		return NULL;
+
+	return slits;
+}
+
 
 /**
  * @brief    Interpret the command line options and execute the data processing
@@ -384,6 +503,7 @@ static int fors_normalise_flat(cpl_parameterlist *parlist,
     int         disp_nknots;
     int         sradius;
     int         dradius;
+    int         dradius_aver;
     float       splfit_threshold;
 
     /*
@@ -468,11 +588,11 @@ static int fors_normalise_flat(cpl_parameterlist *parlist,
             "fors.fors_normalise_flat.sradius", NULL);
     dradius = dfs_get_parameter_int(parlist, 
             "fors.fors_normalise_flat.dradius", NULL);
+    dradius_aver = dfs_get_parameter_int(parlist, 
+            "fors.fors_normalise_flat.dradius_aver", grism_table);
     splfit_threshold = dfs_get_parameter_double(parlist, 
             "fors.fors_normalise_flat.splfit_threshold", NULL);
 
-    cpl_table_delete(grism_table); grism_table = NULL;
-
     if (cpl_error_get_code())
         fors_normalise_flat_exit("Failure reading the configuration "
                                  "parameters");
@@ -538,9 +658,9 @@ static int fors_normalise_flat(cpl_parameterlist *parlist,
     }
 
     /* Check for required inputs */
-    if (cpl_frameset_count_tags(frameset, disp_coeff_tag) != 0) {
+    if (cpl_frameset_count_tags(frameset, disp_coeff_tag) != 1) {
         cpl_msg_error(recipe, "One (and only one) %s must be in inputs", 
-                      slit_location_tag);
+        		disp_coeff_tag);
         fors_normalise_flat_exit(NULL);
     }
     if (!(lss || treat_as_lss)) {
@@ -551,7 +671,7 @@ static int fors_normalise_flat(cpl_parameterlist *parlist,
         }
 
 
-        if (cpl_frameset_count_tags(frameset, slit_location_tag) != 0) {
+        if (cpl_frameset_count_tags(frameset, slit_location_tag) != 1) {
             cpl_msg_error(recipe, "One (and only one) %s must be in inputs", 
                           slit_location_tag);
             fors_normalise_flat_exit(NULL);
@@ -604,6 +724,11 @@ static int fors_normalise_flat(cpl_parameterlist *parlist,
 
     cpl_msg_info(recipe, "The central wavelength is: %.2f", reference);
 
+    std::unique_ptr<mosca::grism_config> grism_cfg =
+            fors_grism_config_from_table(grism_table, reference);
+
+    cpl_table_delete(grism_table); grism_table = NULL;
+
     rebin = cpl_propertylist_get_int(header, "ESO DET WIN1 BINX");
 
     if (cpl_error_get_code() != CPL_ERROR_NONE)
@@ -623,6 +748,7 @@ static int fors_normalise_flat(cpl_parameterlist *parlist,
     cpl_msg_indent_more();
 
     cpl_frame * master_flat_frame = cpl_frameset_find(frameset, master_flat_tag);
+    cpl_frame_set_group(master_flat_frame, CPL_FRAME_GROUP_CALIB);
     master_flat_f = fors_image_load(master_flat_frame);
     if (master_flat_f == NULL)
         fors_normalise_flat_exit("Cannot load master flat field frame");
@@ -643,6 +769,44 @@ static int fors_normalise_flat(cpl_parameterlist *parlist,
     /* The normaliser object */
     fors::flat_normaliser normaliser;
 
+    /*User supplied slit locations and curve coefficients (MUX and MOS)*/
+    if (!(lss || treat_as_lss)) {
+		slits = dfs_load_table(frameset, slit_location_tag, 1);
+		if (slits == NULL)
+			fors_normalise_flat_exit("Cannot load slits location table");
+
+		polytraces = dfs_load_table(frameset, curv_coeff_tag, 1);
+		if (slits == NULL)
+			fors_normalise_flat_exit("Cannot load spectral curvature table");
+    }else{
+    	/*LSS or LONG MOS*/
+    	cpl_size last_row = 0, first_row = 0;
+    	cpl_error_code fail = get_rows(disp_coeff, master_flat, first_row, last_row);
+
+    	if(fail)
+			fors_normalise_flat_exit("Cannot generate data for LSS");
+
+    	slits = generate_dummy_slits_table(disp_coeff, master_flat,
+    			first_row, last_row);
+    	polytraces = generate_dummy_polytraces(first_row, last_row);
+
+    	if(!slits || !polytraces)
+			fors_normalise_flat_exit("Cannot generate data for LSS");
+
+    }
+
+    nx = master_flat.size_dispersion();
+    ny = master_flat.size_spatial();
+
+    /* Get the detected slit locations */
+     fors::detected_slits det_slits =
+         fors::detected_slits_from_tables(slits, polytraces,
+                 master_flat.size_dispersion());
+
+     /* Get the calibrated slits */
+     fors::calibrated_slits calib_slits = fors::create_calibrated_slits(det_slits,
+    		 wave_cal, *grism_cfg, nx, ny);
+
     if (lss || treat_as_lss) {
 
         /* FIXME:
@@ -659,27 +823,16 @@ static int fors_normalise_flat(cpl_parameterlist *parlist,
          * curvature model may be provided in input, in future releases.
          */
 
-        normaliser.lss_normalise(master_flat, wave_cal, sradius, dradius, 
-                                 spa_polyorder, disp_nknots, splfit_threshold);
+        normaliser.lss_normalise(master_flat, wave_cal, calib_slits,
+                sradius, dradius, dradius_aver, spa_polyorder,
+                disp_nknots, splfit_threshold);
+
     }
-    else
-    {
+    else {
 
         /*
          * This is the generic MOS/MXU handling
          */
-
-        slits = dfs_load_table(frameset, slit_location_tag, 1);
-        if (slits == NULL)
-            fors_normalise_flat_exit("Cannot load slits location table");
-
-        polytraces = dfs_load_table(frameset, curv_coeff_tag, 1);
-        if (slits == NULL)
-            fors_normalise_flat_exit("Cannot load spectral curvature table");
-
-        nx = master_flat.size_dispersion();
-        ny = master_flat.size_spatial();
-
         coordinate = cpl_image_new(nx, ny, CPL_TYPE_FLOAT);
         spatial = mos_spatial_calibration(master_flat.get_cpl_image(),
                 slits, polytraces, 
@@ -689,24 +842,26 @@ static int fors_normalise_flat(cpl_parameterlist *parlist,
 
         cpl_image_delete(spatial); spatial = NULL;
 
-        normaliser.mos_normalise(master_flat, wave_cal, coordinate, slits, polytraces,
-                startwavelength, endwavelength,
-                dispersion, sradius, dradius,
-                spa_polyorder, disp_nknots, splfit_threshold);
+        normaliser.mos_normalise(master_flat, wave_cal, coordinate, calib_slits,
+                slits, polytraces, startwavelength, endwavelength,
+                dispersion, sradius, dradius, dradius_aver,
+	       	spa_polyorder, disp_nknots, splfit_threshold);
 
         cpl_image_delete(coordinate); coordinate = NULL;
-        cpl_table_delete(polytraces); polytraces = NULL;
-        cpl_table_delete(slits); slits = NULL;
+
     }
 
+    cpl_table_delete(polytraces); polytraces = NULL;
+    cpl_table_delete(slits); slits = NULL;
 
     /* Save the normalised image */
+    cpl_propertylist_append_int(header, "ESO QC RESP FLAT_DRADIUS_AVER", dradius_aver);
     fors_image * norm_flat = fors_image_new(
             cpl_image_duplicate(master_flat.get_cpl_image()),
             cpl_image_power_create(master_flat.get_cpl_image_err(), 2.));
     fors_dfs_save_image_err(frameset, norm_flat,
                             master_norm_flat_tag, header, NULL, parlist,
-                            recipe, master_flat_frame);
+                            recipe, master_flat_frame, NULL);
     if(cpl_error_get_code() != CPL_ERROR_NONE)
         fors_normalise_flat_exit(NULL);
     cpl_propertylist_delete(header); header = NULL;
