@@ -37,6 +37,7 @@
 #include <fors_stack.h>
 #include <fors_dfs.h>
 #include <fors_header.h>
+#include <fors_utils.h>
 
 #define OFFSET    50
 #define TOLERANCE 10
@@ -145,7 +146,7 @@ cpl_table_delete(global);                     \
 cpl_table_delete(wavelengths);                \
 cpl_vector_delete(lines);                     \
 cpl_msg_indent_less();                        \
-return -1;                                    \
+return fors_get_error_for_exit();             \
 }
 
 #define fors_pmos_calib_exit_memcheck(message)       \
@@ -1560,6 +1561,7 @@ static int fors_pmos_calib(cpl_parameterlist *parlist, cpl_frameset *frameset)
                 }
                 else {
                     same_offset = 1; /* FIXLANDER slit_ident = 0; */
+
                     cpl_msg_info(recipe, 
                                  "Global distortion model cannot be computed");
                     if (cpl_error_get_code() != CPL_ERROR_NONE) {
