@@ -608,7 +608,7 @@ static int fors_flat(cpl_parameterlist *parlist, cpl_frameset *frameset)
         wave_ref *= 10;
 
     cpl_frameset * grism_frame = fors_frameset_extract(frameset, "GRISM_TABLE");
-    std::auto_ptr<mosca::grism_config> grism_cfg = 
+    std::unique_ptr<mosca::grism_config> grism_cfg =
             fors_grism_config_from_frame(cpl_frameset_get_position(grism_frame, 0), wave_ref);
 
     
@@ -625,7 +625,8 @@ static int fors_flat(cpl_parameterlist *parlist, cpl_frameset *frameset)
 
     
     /* Get the calibrated slits */
-    fors::calibrated_slits calib_slits(det_slits, wave_cal, *grism_cfg,
+    fors::calibrated_slits calib_slits = fors::create_calibrated_slits(
+    								   det_slits, wave_cal, *grism_cfg,
                                        basiccal_flats[0].size_dispersion(),
                                        basiccal_flats[0].size_spatial()); 
 
@@ -639,7 +640,7 @@ static int fors_flat(cpl_parameterlist *parlist, cpl_frameset *frameset)
 
     /* Computing master flat */
     cpl_msg_info(cpl_func, "Computing master flat");
-    std::auto_ptr<mosca::image> master_flat;
+    std::unique_ptr<mosca::image> master_flat;
     if(stack_method == "mean" || stack_method == "sum")
     {
         mosca::reduce_mean reduce_method;
