@@ -34,6 +34,7 @@
 #include <moses.h>
 #include <fors_dfs.h>
 #include <fors_qc.h>
+#include <fors_utils.h>
 
 static int fors_sumflux_create(cpl_plugin *);
 static int fors_sumflux_exec(cpl_plugin *);
@@ -72,7 +73,7 @@ cpl_propertylist_delete(header);              \
 cpl_propertylist_delete(qclist);              \
 cpl_table_delete(overscans);                  \
 cpl_msg_indent_less();                        \
-return -1;                                    \
+return fors_get_error_for_exit();             \
 }
 
 #define fors_sumflux_exit_memcheck(message)   \
