@@ -376,7 +376,6 @@ static int fors_trace_flat(cpl_parameterlist *parlist,
     int         nx, ny;
     int         treat_as_lss;
     double      reference;
-    double      mxpos;
     int         nslits_out_det = 0;
 
     char       *instrume = NULL;
@@ -567,9 +566,9 @@ static int fors_trace_flat(cpl_parameterlist *parlist,
     treat_as_lss = fors_mos_is_lss_like(maskslits, nslits_out_det);
 
     if (treat_as_lss) {
-        cpl_msg_error(recipe, "All slits have the same offset: %.2f mm\n"
+        cpl_msg_error(recipe, "All slits have the same offset\n"
                       "Spectra are not traceable: the LSS data reduction\n"
-                      "strategy must be applied.", mxpos);
+                      "strategy must be applied.");
         fors_trace_flat_exit(NULL);
     }
 
