@@ -443,7 +443,8 @@ static int fors_wave_calib_lss(cpl_parameterlist *parlist,
     double     *line;
     double     *fiterror = NULL;
     int        *fitlines = NULL;
-    int         nx, ny;
+    int         nx;
+    cpl_size    ny;
     int         first_row, last_row;
     int         ylow, yhig;
     double      reference;
@@ -844,7 +845,8 @@ static int fors_wave_calib_lss(cpl_parameterlist *parlist,
         if (!cpl_table_is_valid(idscoeff, "c0", i))
             cpl_table_set_invalid(idscoeff, "error", i);
 
-    cpl_msg_info(recipe, "Valid solutions found: %ld out of %ld rows",
+    cpl_msg_info(recipe, "Valid solutions found: %"CPL_SIZE_FORMAT
+                 " out of %"CPL_SIZE_FORMAT" rows",
                  ny - cpl_table_count_invalid(idscoeff, "c0"), ny);
 
     cpl_image_delete(spectra); spectra = NULL;
