@@ -164,7 +164,7 @@ Arc line coverage may vary with slit position."""
     def plotSpatialMap(self) :
       if self.slit_map is not None:
         title_slit_map   = 'Slit spatial map'
-        tooltip_slit_map ="""Reduced arc lamp frame."""
+        tooltip_slit_map ="""Spatial map. The pixel value indicates the distance from the top of the slit"""
         self.slit_map.plot(self.subplot_slit_map, title_slit_map,
                            tooltip_slit_map)
 
@@ -307,8 +307,9 @@ the dispersion relation there will be extrapolated."""
     # Note also that parameters have to be prefixed by the 'recipe name:'
     def setInteractiveParameters(self):
       paramList = list()
-      paramList.append(reflex.RecipeParameter('fors_calib','sradius',group='flat field norm',description='Smooth box radius for flat field along spatial direction (used if s_knots < 0)'))
-      paramList.append(reflex.RecipeParameter('fors_calib','dradius',group='flat field norm',description='Smooth box radius for flat field along dispersion direction (if d_knots < 0)'))
+      paramList.append(reflex.RecipeParameter('fors_calib','sradius',group='flat field norm',description='Smooth box radius for flat field along spatial direction'))
+      paramList.append(reflex.RecipeParameter('fors_calib','dradius',group='flat field norm',description='Smooth box radius (median) for flat field along dispersion direction'))
+      paramList.append(reflex.RecipeParameter('fors_calib','dradius_aver',group='flat field norm',description='Smooth box radius (average) for flat field along dispersion direction'))
       paramList.append(reflex.RecipeParameter('fors_calib','s_degree',group='flat field norm',description='Polynomial degree for the flat field fitting along spatial direction'))
       paramList.append(reflex.RecipeParameter('fors_calib','d_nknots',group='flat field norm',description='Number of knots in flat field fitting splines along dispersion direction'))
       paramList.append(reflex.RecipeParameter('fors_calib','fit_threshold',group='flat field norm',description='Threshold percentage for flat spline fitting with respect to the maximum'))
