@@ -1,4 +1,6 @@
 # import the needed modules
+from __future__ import absolute_import
+from __future__ import print_function
 try:
   import reflex
   import matplotlib.gridspec
@@ -199,7 +201,7 @@ In this window, the user will interact with the FORS response computation"""
 
 except ImportError:
   import_sucess = 'false'
-  print "Error importing modules pyfits, wx, matplotlib, numpy"
+  print("Error importing modules pyfits, wx, matplotlib, numpy")
 
 #This is the 'main' function
 if __name__ == '__main__':
